@@ -1,18 +1,18 @@
 /* BEGIN software license
  *
- * MsXpertSuite - mass spectrometry software suite
+ * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2026 Filippo Rusconi
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
- * This file is part of the MsXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- * The MsXpertSuite project is the successor of the massXpert project. This
+ * The msXpertSuite project is the successor of the massXpert project. This
  * project now includes various independent modules:
  *
- * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
- * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,33 +31,23 @@
  */
 
 
-#pragma once
-
-/////////////////////// stdlib includes
+#ifndef CALCULATOR_RECORDER_DLG_HPP
+#define CALCULATOR_RECORDER_DLG_HPP
 
 
 /////////////////////// Qt includes
 
 
-/////////////////////// pappsomspp includes
-
-
-/////////////////////// libXpertMass includes
-
-
-/////////////////////// libXpertMassGui includes
-
-
 /////////////////////// Local includes
-
 #include "ui_CalculatorRecorderDlg.h"
 
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace MassXpert
-{
+	namespace massxpert
+	{
+
 
 
 class CalculatorRecorderDlg : public QDialog
@@ -80,6 +70,9 @@ class CalculatorRecorderDlg : public QDialog
   void close();
 };
 
+} // namespace massxpert
 
-} // namespace MassXpert
-} // namespace MsXpS
+} // namespace msxps
+
+
+#endif // CALCULATOR_RECORDER_DLG_HPP
