@@ -33,39 +33,33 @@
 
 /////////////////////// Qt includes
 #include <QMessageBox>
-#include <QSettings>
-
-
-/////////////////////// libmass includes
-#include <libXpertMass/PolChemDef.hpp>
-#include <libXpertMass/PolChemDefEntity.hpp>
 
 
 /////////////////////// Local includes
 #include "CleaveSpecDefDlg.hpp"
+#include "../nongui/PolChemDef.hpp"
 #include "PolChemDefWnd.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace massxpert
-{
+	namespace massxpert
+	{
 
 
-CleaveSpecDefDlg::CleaveSpecDefDlg(libXpertMass::PolChemDefSPtr polChemDefSPtr,
+
+CleaveSpecDefDlg::CleaveSpecDefDlg(PolChemDef *polChemDef,
                                    PolChemDefWnd *polChemDefWnd,
-                                   const QString &settingsFilePath,
-                                   const QString &applicationName,
-                                   const QString &description)
-  : AbstractPolChemDefDependentDlg(polChemDefSPtr,
-                                   polChemDefWnd,
-                                   settingsFilePath,
-                                   "CleaveSpecDefDlg",
-                                   applicationName,
-                                   description)
+                                   const QString &settingsFilePath)
+  : AbstractPolChemDefDependentDlg{
+      polChemDef,
+      polChemDefWnd,
+      settingsFilePath,
+      "CleaveSpecDefDlg",
+      "massXpert: Cleavage specification definition"}
 {
-  mp_list = polChemDefSPtr->cleaveSpecListPtr();
+  mp_list = polChemDef->cleaveSpecListPtr();
 
   if(!initialize())
     qFatal(
@@ -126,15 +120,11 @@ CleaveSpecDefDlg::initialize()
 {
   m_ui.setupUi(this);
 
-  // Now we need to actually show the window title (that element is empty in
-  // m_ui)
-  displayWindowTitle();
-
   // Set all the cleaveSpecs to the list widget.
 
   for(int iter = 0; iter < mp_list->size(); ++iter)
     {
-      libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(iter);
+      CleaveSpec *cleaveSpec = mp_list->at(iter);
 
       m_ui.cleaveSpecListWidget->addItem(cleaveSpec->name());
     }
@@ -221,8 +211,8 @@ CleaveSpecDefDlg::addCleaveSpecPushButtonClicked()
   // Returns -1 if the list is empty.
   int index = m_ui.cleaveSpecListWidget->currentRow();
 
-  libXpertMass::CleaveSpec *newCleaveSpec = new libXpertMass::CleaveSpec(
-    msp_polChemDef, tr("Type Spec Name"), tr("Type Pattern"));
+  CleaveSpec *newCleaveSpec =
+    new CleaveSpec(mp_polChemDef, tr("Type Spec Name"), tr("Type Pattern"));
 
   mp_list->insert(index, newCleaveSpec);
   m_ui.cleaveSpecListWidget->insertItem(index, newCleaveSpec->name());
@@ -261,7 +251,7 @@ CleaveSpecDefDlg::removeCleaveSpecPushButtonClicked()
   QListWidgetItem *item = m_ui.cleaveSpecListWidget->takeItem(index);
   delete item;
 
-  libXpertMass::CleaveSpec *cleaveSpec = mp_list->takeAt(index);
+  CleaveSpec *cleaveSpec = mp_list->takeAt(index);
   Q_ASSERT(cleaveSpec);
   delete cleaveSpec;
 
@@ -369,17 +359,17 @@ CleaveSpecDefDlg::addCleaveRulePushButtonClicked()
       return;
     }
 
-  // Get the index of the current cleaveSpec so that we know to which
-  // cleaveSpec we'll add the cleaveRule.
+  // Get the index of the current cleaveSpec so that we know to which cleaveSpec
+  // we'll add the cleaveRule.
   int index = m_ui.cleaveSpecListWidget->currentRow();
 
   // What's the actual cleaveSpec?
-  libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(index);
+  CleaveSpec *cleaveSpec = mp_list->at(index);
   Q_ASSERT(cleaveSpec);
 
   // Allocate the new cleaveRule.
-  libXpertMass::CleaveRule *newCleaveRule =
-    new libXpertMass::CleaveRule(msp_polChemDef, tr("Type Rule Name"));
+  CleaveRule *newCleaveRule =
+    new CleaveRule(mp_polChemDef, tr("Type Rule Name"));
 
   // Get the row index of the current cleaveRule item. Returns -1 if the
   // list is empty.
@@ -418,7 +408,7 @@ CleaveSpecDefDlg::removeCleaveRulePushButtonClicked()
   // which cleaveSpec we'll remove the cleaveRule.
   int index = m_ui.cleaveSpecListWidget->currentRow();
 
-  libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(index);
+  CleaveSpec *cleaveSpec = mp_list->at(index);
   Q_ASSERT(cleaveSpec);
 
   // Get the index of the current cleaveRule.
@@ -433,9 +423,9 @@ CleaveSpecDefDlg::removeCleaveRulePushButtonClicked()
 
   // Remove the cleaveRule from the cleaveSpec proper.
 
-  QList<libXpertMass::CleaveRule *> *cleaveRuleList = cleaveSpec->ruleList();
+  QList<CleaveRule *> *cleaveRuleList = cleaveSpec->ruleList();
 
-  libXpertMass::CleaveRule *cleaveRule = cleaveRuleList->at(index);
+  CleaveRule *cleaveRule = cleaveRuleList->at(index);
 
   cleaveSpec->ruleList()->removeAt(index);
   delete cleaveRule;
@@ -479,8 +469,8 @@ CleaveSpecDefDlg::moveUpCleaveRulePushButtonClicked()
     return;
 
   // Get the cleaveSpec to which the cleaveRule belongs.
-  int index                       = m_ui.cleaveSpecListWidget->currentRow();
-  libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(index);
+  int index              = m_ui.cleaveSpecListWidget->currentRow();
+  CleaveSpec *cleaveSpec = mp_list->at(index);
 
   // Get the index of the current cleaveRule item.
   index = m_ui.cleaveRuleListWidget->currentRow();
@@ -490,7 +480,7 @@ CleaveSpecDefDlg::moveUpCleaveRulePushButtonClicked()
     return;
 
   // Get the cleaveRule itself from the cleaveSpec.
-  libXpertMass::CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(index);
+  CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(index);
 
   cleaveSpec->ruleList()->removeAt(index);
   cleaveSpec->ruleList()->insert(index - 1, cleaveRule);
@@ -518,8 +508,8 @@ CleaveSpecDefDlg::moveDownCleaveRulePushButtonClicked()
     return;
 
   // Get the cleaveSpec to which the cleaveRule belongs.
-  int index                       = m_ui.cleaveSpecListWidget->currentRow();
-  libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(index);
+  int index              = m_ui.cleaveSpecListWidget->currentRow();
+  CleaveSpec *cleaveSpec = mp_list->at(index);
 
   // Get the index of the current cleaveRule item.
   index = m_ui.cleaveRuleListWidget->currentRow();
@@ -529,7 +519,7 @@ CleaveSpecDefDlg::moveDownCleaveRulePushButtonClicked()
     return;
 
   // Get the cleaveRule itself from the cleaveSpec.
-  libXpertMass::CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(index);
+  CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(index);
 
   cleaveSpec->ruleList()->removeAt(index);
   cleaveSpec->ruleList()->insert(index + 1, cleaveRule);
@@ -559,7 +549,7 @@ CleaveSpecDefDlg::applyCleaveSpecPushButtonClicked()
   // Get the index of the current cleaveSpec item.
   int index = m_ui.cleaveSpecListWidget->currentRow();
 
-  libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(index);
+  CleaveSpec *cleaveSpec = mp_list->at(index);
 
   // We do not want more than one cleaveSpec by the same name or the same
   // symbol.
@@ -571,7 +561,7 @@ CleaveSpecDefDlg::applyCleaveSpecPushButtonClicked()
   // cleaveSpec is not the one that is current in the cleaveSpec list,
   // then we are making a double entry, which is not allowed.
 
-  int nameRes = libXpertMass::CleaveSpec::isNameInList(editName, *mp_list);
+  int nameRes = CleaveSpec::isNameInList(editName, *mp_list);
   if(nameRes != -1 && nameRes != index)
     {
       QMessageBox::warning(this,
@@ -581,7 +571,7 @@ CleaveSpecDefDlg::applyCleaveSpecPushButtonClicked()
       return;
     }
 
-  libXpertMass::CleaveSpec newSpec(msp_polChemDef, "NOT_SET", editPattern);
+  CleaveSpec newSpec(mp_polChemDef, "NOT_SET", editPattern);
   if(!newSpec.parse())
     {
       QMessageBox::warning(this,
@@ -617,14 +607,14 @@ CleaveSpecDefDlg::applyCleaveRulePushButtonClicked()
     return;
 
   // Get the cleaveSpec to which the cleaveRule belongs.
-  int index                       = m_ui.cleaveSpecListWidget->currentRow();
-  libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(index);
+  int index              = m_ui.cleaveSpecListWidget->currentRow();
+  CleaveSpec *cleaveSpec = mp_list->at(index);
 
   // Get the index of the current cleaveRule item.
   index = m_ui.cleaveRuleListWidget->currentRow();
 
   // Get the cleaveRule itself from the cleaveSpec.
-  libXpertMass::CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(index);
+  CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(index);
 
   QString editName = m_ui.cleaveRuleNameLineEdit->text();
 
@@ -634,14 +624,11 @@ CleaveSpecDefDlg::applyCleaveRulePushButtonClicked()
   QString rightCode    = m_ui.rightCodeLineEdit->text();
   QString rightFormula = m_ui.rightFormulaLineEdit->text();
 
-  qDebug() << "Oh yeah! The right formula is:" << rightFormula;
-
   // If a cleaveRule is found in the list with the same name, and that
   // cleaveRule is not the one that is current in the cleaveRule list,
   // then we are making a double entry, which is not allowed.
 
-  int nameRes =
-    libXpertMass::CleaveRule::isNameInList(editName, *cleaveSpec->ruleList());
+  int nameRes = CleaveRule::isNameInList(editName, *cleaveSpec->ruleList());
   if(nameRes != -1 && nameRes != index)
     {
       QMessageBox::warning(this,
@@ -654,10 +641,9 @@ CleaveSpecDefDlg::applyCleaveRulePushButtonClicked()
 
   if(!leftCode.isEmpty())
     {
-      const QList<libXpertMass::Monomer *> &monomerList =
-        msp_polChemDef->monomerList();
+      const QList<Monomer *> &monomerList = mp_polChemDef->monomerList();
 
-      if(libXpertMass::Monomer::isCodeInList(leftCode, monomerList) == -1)
+      if(Monomer::isCodeInList(leftCode, monomerList) == -1)
         {
           QMessageBox::warning(this,
                                tr("massXpert - Cleavage definition"),
@@ -665,29 +651,27 @@ CleaveSpecDefDlg::applyCleaveRulePushButtonClicked()
                                QMessageBox::Ok);
           return;
         }
-
-
-      libXpertMass::Formula formula(leftFormula);
-
-      libXpertMass::IsotopicDataSPtr isotopic_data_sp =
-        msp_polChemDef->getIsotopicDataSPtr();
-
-      if(!formula.validate(isotopic_data_sp))
-        {
-          QMessageBox::warning(this,
-                               tr("massXpert - libXpertMass::Monomer definition"),
-                               tr("The formula failed to validate."),
-                               QMessageBox::Ok);
-          return;
-        }
     }
 
+  {
+    Formula formula(leftFormula);
+
+    if(!formula.validate(mp_polChemDef->atomList()))
+      {
+        QMessageBox::warning(this,
+                             tr("massXpert - Monomer definition"),
+                             tr("The formula failed to validate."),
+                             QMessageBox::Ok);
+        return;
+      }
+  }
+
+
   if(!rightCode.isEmpty())
     {
-      const QList<libXpertMass::Monomer *> &monomerList =
-        msp_polChemDef->monomerList();
+      const QList<Monomer *> &monomerList = mp_polChemDef->monomerList();
 
-      if(libXpertMass::Monomer::isCodeInList(rightCode, monomerList) == -1)
+      if(Monomer::isCodeInList(rightCode, monomerList) == -1)
         {
           QMessageBox::warning(this,
                                tr("massXpert - Cleavage definition"),
@@ -695,22 +679,21 @@ CleaveSpecDefDlg::applyCleaveRulePushButtonClicked()
                                QMessageBox::Ok);
           return;
         }
-
-      libXpertMass::Formula formula(rightFormula);
-
-      libXpertMass::IsotopicDataSPtr isotopic_data_sp =
-        msp_polChemDef->getIsotopicDataSPtr();
-
-      if(!formula.validate(isotopic_data_sp))
-        {
-          QMessageBox::warning(this,
-                               tr("massXpert - libXpertMass::Monomer definition"),
-                               tr("The formula failed to validate."),
-                               QMessageBox::Ok);
-          return;
-        }
     }
 
+  {
+    Formula formula(rightFormula);
+
+    if(!formula.validate(mp_polChemDef->atomList()))
+      {
+        QMessageBox::warning(this,
+                             tr("massXpert - Monomer definition"),
+                             tr("The formula failed to validate."),
+                             QMessageBox::Ok);
+        return;
+      }
+  }
+
   cleaveRule->setName(editName);
 
   cleaveRule->setLeftCode(leftCode);
@@ -757,7 +740,7 @@ CleaveSpecDefDlg::validatePushButtonClicked()
     {
       QListWidgetItem *item = m_ui.cleaveSpecListWidget->item(iter);
 
-      libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(iter);
+      CleaveSpec *cleaveSpec = mp_list->at(iter);
 
       if(item->text() != cleaveSpec->name())
         errorList << QString(tr("\nCleavage at index %1 has not the same\n"
@@ -807,7 +790,7 @@ CleaveSpecDefDlg::cleaveSpecListWidgetItemSelectionChanged()
   // Get the index of the current cleaveSpec.
   int index = m_ui.cleaveSpecListWidget->currentRow();
 
-  libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(index);
+  CleaveSpec *cleaveSpec = mp_list->at(index);
   Q_ASSERT(cleaveSpec);
 
   // Set the data of the cleaveSpec to their respective widgets.
@@ -818,7 +801,7 @@ CleaveSpecDefDlg::cleaveSpecListWidgetItemSelectionChanged()
 
   for(int iter = 0; iter < cleaveSpec->ruleList()->size(); ++iter)
     {
-      libXpertMass::CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(iter);
+      CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(iter);
 
       m_ui.cleaveRuleListWidget->addItem(cleaveRule->name());
     }
@@ -850,7 +833,7 @@ CleaveSpecDefDlg::cleaveRuleListWidgetItemSelectionChanged()
   int index = m_ui.cleaveSpecListWidget->currentRow();
 
   // Find the cleaveRule object in the list of cleaveRules.
-  libXpertMass::CleaveSpec *cleaveSpec = mp_list->at(index);
+  CleaveSpec *cleaveSpec = mp_list->at(index);
   Q_ASSERT(cleaveSpec);
 
   // Get the index of the current cleaveRule.
@@ -858,7 +841,7 @@ CleaveSpecDefDlg::cleaveRuleListWidgetItemSelectionChanged()
 
   // Get the cleaveRule that is currently selected from the cleaveSpec's list
   // of cleaveRules.
-  libXpertMass::CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(index);
+  CleaveRule *cleaveRule = cleaveSpec->ruleList()->at(index);
   Q_ASSERT(cleaveRule);
 
   // Set the data of the cleaveRule to their respective widgets.
@@ -867,8 +850,7 @@ CleaveSpecDefDlg::cleaveRuleListWidgetItemSelectionChanged()
 
 
 void
-CleaveSpecDefDlg::updateCleaveSpecIdentityDetails(
-  libXpertMass::CleaveSpec *cleaveSpec)
+CleaveSpecDefDlg::updateCleaveSpecIdentityDetails(CleaveSpec *cleaveSpec)
 {
   if(cleaveSpec)
     {
@@ -884,17 +866,17 @@ CleaveSpecDefDlg::updateCleaveSpecIdentityDetails(
 
 
 void
-CleaveSpecDefDlg::updateCleaveRuleDetails(libXpertMass::CleaveRule *cleaveRule)
+CleaveSpecDefDlg::updateCleaveRuleDetails(CleaveRule *cleaveRule)
 {
   if(cleaveRule)
     {
       m_ui.cleaveRuleNameLineEdit->setText(cleaveRule->name());
 
       m_ui.leftCodeLineEdit->setText(cleaveRule->leftCode());
-      m_ui.leftFormulaLineEdit->setText(cleaveRule->leftFormula().toString());
+      m_ui.leftFormulaLineEdit->setText(cleaveRule->leftFormula().text());
 
       m_ui.rightCodeLineEdit->setText(cleaveRule->rightCode());
-      m_ui.rightFormulaLineEdit->setText(cleaveRule->rightFormula().toString());
+      m_ui.rightFormulaLineEdit->setText(cleaveRule->rightFormula().text());
     }
   else
     {
@@ -934,4 +916,4 @@ CleaveSpecDefDlg::validate()
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
