@@ -1,18 +1,18 @@
 /* BEGIN software license
  *
- * MsXpertSuite - mass spectrometry software suite
+ * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2026 Filippo Rusconi
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
- * This file is part of the MsXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- * The MsXpertSuite project is the successor of the massXpert project. This
+ * The msXpertSuite project is the successor of the massXpert project. This
  * project now includes various independent modules:
  *
- * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
- * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,61 +34,56 @@
 /////////////////////// Qt includes
 #include <QMessageBox>
 #include <QFileDialog>
-#include <QSettings>
-
-
-/////////////////////// libXpertMass includes
-#include <MsXpS/libXpertMassCore/CrossLink.hpp>
-#include <MsXpS/libXpertMassCore/Monomer.hpp>
-#include <MsXpS/libXpertMassCore/Ionizer.hpp>
-
 
 /////////////////////// Local includes
 #include "CompositionsDlg.hpp"
+#include "../nongui/Coordinates.hpp"
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace MassXpert
-{
+	namespace massxpert
+	{
 
 
-CompositionsDlg::CompositionsDlg(SequenceEditorWnd *editor_wnd_p,
-                                 libXpertMassCore::PolymerQSPtr polymer_sp,
-                                 /* no libXpertMassCore::PolChemDef **/
-                                 const QString &config_settings_file_path,
-                                 const QString &application_name,
-                                 const QString &description,
-                                 const libXpertMassCore::CalcOptions &calc_options,
-                                 const libXpertMassCore::Ionizer &ionizer)
-  : AbstractSeqEdWndDependentDlg(editor_wnd_p,
-                                 polymer_sp,
-                                 nullptr /*polChemDef*/,
-                                 config_settings_file_path,
+
+CompositionsDlg::CompositionsDlg(SequenceEditorWnd *editorWnd,
+                                 Polymer *polymer,
+                                 /* no PolChemDef **/
+                                 const QString &configSettingsFilePath,
+                                 CalcOptions *calcOptions,
+                                 IonizeRule *ionizeRule)
+  : AbstractSeqEdWndDependentDlg(editorWnd,
+                                 polymer,
+                                 0 /*polChemDef*/,
+                                 configSettingsFilePath,
                                  "CompositionsDlg",
-                                 application_name,
-                                 description),
-    mref_calcOptions(calc_options),
-    m_ionizer(ionizer)
+                                 "Composition calculations"),
+    mp_calcOptions{calcOptions},
+    mp_ionizeRule{ionizeRule}
 {
-  if(polymer_sp == nullptr)
-    qFatal() << "Programming error. Pointer cannot be nullptr.";
+  if(!mp_polymer)
+    qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
+
+  if(!mp_calcOptions || !mp_ionizeRule)
+    qFatal("Fatal error at %s@%d. Program aborted.", __FILE__, __LINE__);
 
   if(!initialize())
-    qFatal()
-      << "Programming error. Failed to initialize the dialog window"
-      << m_wndTypeName.toLatin1().data();
-
-  setWindowTitle(QString("%1 - %2").arg(application_name).arg(description));
+    qFatal(
+      "Fatal error at %s@%d. Failed to initialize the %s window. Program "
+      "aborted.",
+      __FILE__,
+      __LINE__,
+      m_wndTypeName.toLatin1().data());
 }
 
 
 CompositionsDlg::~CompositionsDlg()
 {
-  writeSettings();
-
   delete mpa_compositionTreeViewModel;
+
   delete mpa_compositionProxyModel;
+
   delete mpa_resultsString;
 
   freeMonomerList();
@@ -124,13 +119,6 @@ CompositionsDlg::initialize()
 {
   m_ui.setupUi(this);
 
-  setWindowIcon(qApp->windowIcon());
-
-  // Update the window title because the window title element in m_ui might be
-  // either erroneous or empty.
-  setWindowTitle(
-    QString("%1 - %2").arg(m_applicationName).arg(m_windowDescription));
-
   updateSelectionData();
 
   setupTreeView();
@@ -150,6 +138,8 @@ CompositionsDlg::initialize()
 
   mpa_resultsString = new QString();
 
+  //////////////////////////////////// The results-exporting menus.
+
   readSettings();
 
   connect(m_ui.updateSelectionDataPushButton,
@@ -176,11 +166,10 @@ CompositionsDlg::updateSelectionData()
 {
   // The selection might exist as a list of region selections.
 
-  if(mp_editorWnd->mpa_editorGraphicsView->selectionIndices(
-       m_indexRangeCollection))
+  if(mp_editorWnd->mpa_editorGraphicsView->selectionIndices(&m_coordinateList))
     {
       m_ui.selectionCoordinatesLineEdit->setText(
-        m_indexRangeCollection.positionsAsText());
+        m_coordinateList.positionsAsText());
 
       m_ui.selectedSequenceRadioButton->setChecked(true);
     }
@@ -198,42 +187,38 @@ CompositionsDlg::updateSelectionData()
 bool
 CompositionsDlg::fetchValidateInputData()
 {
-  qsizetype polymer_size = (qsizetype)msp_polymer->size();
-
   if(!m_ui.selectedSequenceRadioButton->isChecked())
     {
-      m_indexRangeCollection.setIndexRange(
-        libXpertMassCore::IndexRange(0, polymer_size - 1));
+      m_coordinateList.setCoordinates(Coordinates(0, mp_polymer->size() - 1));
     }
 
   // Make sure the sequence still has a number of residues
-  // compatible with the current m_indexRangeCollection. this because the
+  // compatible with the current m_coordinateList. this because the
   // sequence might be edited between opening this dialog window and
   // actually using it.
 
-  foreach(const libXpertMassCore::IndexRange *item,
-          m_indexRangeCollection.getRangesCstRef())
+  int polymerSize = mp_polymer->size();
+
+  for(int iter = 0; iter < m_coordinateList.size(); ++iter)
     {
-      if(item->m_start >= polymer_size || item->m_stop >= polymer_size)
+      // New coordinates instance we are iterating into.
+      Coordinates *coordinates = m_coordinateList.at(iter);
+
+      if(coordinates->start() >= polymerSize ||
+         coordinates->end() >= polymerSize)
         {
           QMessageBox::warning(0,
-                               tr("MassXpert3 - Compositions"),
-                               tr("Sequence selection data are no more valid.\n"
+                               tr("massXpert - Compositions"),
+                               tr("Selection data are no more valid.\n"
                                   "Please update these data."),
                                QMessageBox::Ok);
           return false;
         }
     }
 
-  // Update the ionization status directly from the sequence editor window,
-  // which, in fact, will ask the Polymer its ionizer.
-
-  libXpertMassCore::Ionizer ionizer = msp_polymer->getIonizerCstRef();
-
   // We also want to know if the cross-links should be taken into account.
 
-  if(static_cast<bool>(mref_calcOptions.getMonomerEntities() &
-                       libXpertMassCore::Enums::ChemicalEntity::CROSS_LINKER))
+  if(mp_calcOptions->monomerEntities() & MONOMER_CHEMENT_CROSS_LINK)
     {
       // If the whole sequence is dealt with, then by definition all
       // the cross-links are encompassed by the sequence.
@@ -245,26 +230,25 @@ CompositionsDlg::fetchValidateInputData()
         }
       else
         {
+          // We have to count the incomplete cross-links.
+
+          const CrossLinkList &crossLinkList = mp_polymer->crossLinkList();
 
           int crossLinkPartial = 0;
-          std::size_t in_count;
-          std::size_t out_count;
 
-          for(const libXpertMassCore::CrossLinkSPtr &cross_link_sp :
-              msp_polymer->getCrossLinksCstRef())
+          for(int iter = 0; iter < crossLinkList.size(); ++iter)
             {
-              libXpertMassCore::Enums::CrossLinkEncompassed ret =
-                cross_link_sp->isEncompassedByIndexRangeCollection(
-                  m_indexRangeCollection, in_count, out_count);
+              CrossLink *crossLink = crossLinkList.at(iter);
 
-              if(ret == libXpertMassCore::Enums::CrossLinkEncompassed::FULLY)
+              int ret = crossLink->encompassedBy(m_coordinateList);
+
+              if(ret == CROSS_LINK_ENCOMPASSED_FULL)
                 {
                   // 		qDebug() << __FILE__ << __LINE__
                   // 			  << "CrossLink at iter:" << iter
                   // 			  << "is fully encompassed";
                 }
-              else if(ret ==
-                      libXpertMassCore::Enums::CrossLinkEncompassed::PARTIALLY)
+              else if(ret == CROSS_LINK_ENCOMPASSED_PARTIAL)
                 {
                   // 		qDebug() << __FILE__ << __LINE__
                   // 			  << "CrossLink at iter:" << iter
@@ -300,13 +284,13 @@ CompositionsDlg::monomericComposition()
   if(!fetchValidateInputData())
     {
       QMessageBox::warning(0,
-                           tr("MassXpert3 - Compositions"),
+                           tr("massXpert - Compositions"),
                            tr("Failed validating input data."),
                            QMessageBox::Ok);
       return;
     }
 
-  libXpertMassCore::Monomer *fakeMonomer = 0;
+  Monomer *fakeMonomer = 0;
 
   // Empty the treeview. This will also remove all the monomer items
   // in the m_monomerList.
@@ -329,20 +313,18 @@ CompositionsDlg::monomericComposition()
       mpa_compositionProxyModel = 0;
     }
 
-  qDebug() << "Determination of the monomeric composition for range:"
-           << m_indexRangeCollection.indicesAsText();
-
-
-  foreach(const libXpertMassCore::IndexRange *item,
-          m_indexRangeCollection.getRangesCstRef())
+  for(int iter = 0; iter < m_coordinateList.size(); ++iter)
     {
-      for(qsizetype iter = item->m_start; iter < item->m_stop + 1; ++iter)
+      // New coordinates instance we are iterating into.
+      Coordinates *coordinates = m_coordinateList.at(iter);
+
+      for(int jter = coordinates->start(); jter < coordinates->end() + 1;
+          ++jter)
         {
           bool processed = false;
 
-          const libXpertMassCore::MonomerCstSPtr monomer_csp =
-            msp_polymer->getSequenceCstRef().getMonomerCstSPtrAt(iter);
-          Q_ASSERT(monomer_csp);
+          const Monomer *iterMonomer = mp_polymer->at(jter);
+          Q_ASSERT(iterMonomer);
 
           // Check if monomer by same name is not already in our list of
           // fake monomers.
@@ -352,9 +334,9 @@ CompositionsDlg::monomericComposition()
               fakeMonomer = m_monomerList.at(kter);
               Q_ASSERT(fakeMonomer);
 
-              if(monomer_csp->getName() == fakeMonomer->getName())
+              if(iterMonomer->name() == fakeMonomer->name())
                 {
-                  libXpertMassCore::Prop *prop = fakeMonomer->prop("MONOMER_COUNT");
+                  Prop *prop = fakeMonomer->prop("MONOMER_COUNT");
 
                   // The fake monomer MUST have a count prop !
                   Q_ASSERT(prop);
@@ -364,12 +346,11 @@ CompositionsDlg::monomericComposition()
                   ++(*count);
                   prop->setData(count);
 
-                  if(monomer_csp->isModified())
+                  if(iterMonomer->isModified())
                     {
                       // The monomer in the sequence is modified. Let the
                       // fake monomer know it.
-                      libXpertMassCore::Prop *prop =
-                        fakeMonomer->prop("MODIF_COUNT");
+                      Prop *prop = fakeMonomer->prop("MODIF_COUNT");
 
                       // The fake monomer might not have a modif prop.
                       if(prop)
@@ -381,8 +362,7 @@ CompositionsDlg::monomericComposition()
                         }
                       else
                         {
-                          libXpertMassCore::IntProp *prop =
-                            new libXpertMassCore::IntProp("MODIF_COUNT", 1);
+                          IntProp *prop = new IntProp("MODIF_COUNT", 1);
                           fakeMonomer->appendProp(prop);
                         }
                     }
@@ -401,19 +381,17 @@ CompositionsDlg::monomericComposition()
 
           if(!processed)
             {
-              fakeMonomer = new libXpertMassCore::Monomer(*monomer_csp);
+              fakeMonomer = iterMonomer->clone();
 
-              libXpertMassCore::IntProp *prop =
-                new libXpertMassCore::IntProp("MONOMER_COUNT", 1);
+              IntProp *prop = new IntProp("MONOMER_COUNT", 1);
               fakeMonomer->appendProp(prop);
 
-              if(monomer_csp->isModified())
+              if(iterMonomer->isModified())
                 {
                   // The monomer in the sequence is modified. Let the
                   // fake monomer know it.
 
-                  libXpertMassCore::IntProp *prop =
-                    new libXpertMassCore::IntProp("MODIF_COUNT", 1);
+                  IntProp *prop = new IntProp("MODIF_COUNT", 1);
                   fakeMonomer->appendProp(prop);
                 }
 
@@ -425,7 +403,7 @@ CompositionsDlg::monomericComposition()
 
       setupTreeView();
 
-      prepareResultsTxtString(CompositionsTarget::MONOMERIC);
+      prepareResultsTxtString(TARGET_MONOMERIC);
 
       setCursor(Qt::ArrowCursor);
     }
@@ -440,18 +418,17 @@ CompositionsDlg::elementalComposition()
   if(!fetchValidateInputData())
     {
       QMessageBox::warning(0,
-                           tr("MassXpert3 - Compositions"),
+                           tr("massXpert - Compositions"),
                            tr("Failed validating input data."),
                            QMessageBox::Ok);
       return;
     }
-  // We let the polymer use its own Ionizer below by not passing
-  // that argument.
-  QString composition = msp_polymer->elementalComposition(
-    m_indexRangeCollection, mref_calcOptions /*, polymer's ionizer*/);
+
+  QString composition = mp_polymer->elementalComposition(
+    *mp_ionizeRule, m_coordinateList, *mp_calcOptions);
   m_ui.elementalCompositionLineEdit->setText(composition);
 
-  prepareResultsTxtString(CompositionsTarget::ELEMENTAL);
+  prepareResultsTxtString(TARGET_ELEMENTAL);
 
   setCursor(Qt::ArrowCursor);
 }
@@ -510,7 +487,7 @@ CompositionsDlg::exportResults(int index)
 
 
 void
-CompositionsDlg::prepareResultsTxtString(CompositionsTarget target)
+CompositionsDlg::prepareResultsTxtString(int target)
 {
   mpa_resultsString->clear();
 
@@ -520,46 +497,48 @@ CompositionsDlg::prepareResultsTxtString(CompositionsTarget target)
     "# Compositions: \n"
     "# -------------\n");
 
-  if(target == CompositionsTarget::ELEMENTAL)
+  if(target == TARGET_ELEMENTAL)
     {
       *mpa_resultsString += QObject::tr("\nIonization rule:\n");
+
       *mpa_resultsString +=
-        QObject::tr("Formula: %1 - ")
-          .arg(m_ionizer.getFormulaRef().getActionFormula());
+        QObject::tr("Formula: %1 - ").arg(mp_ionizeRule->formula());
+
       *mpa_resultsString +=
-        QObject::tr("Charge: %1 - ").arg(m_ionizer.getNominalCharge());
+        QObject::tr("Charge: %1 - ").arg(mp_ionizeRule->charge());
+
       *mpa_resultsString +=
-        QObject::tr("Level: %1\n").arg(m_ionizer.getLevel());
+        QObject::tr("Level: %1\n").arg(mp_ionizeRule->level());
+
+
       *mpa_resultsString += QObject::tr("\nCalculation options:\n");
 
-      bool with_modif_entities =
-        (static_cast<int>(mref_calcOptions.getMonomerEntities()) &
-         static_cast<int>(libXpertMassCore::Enums::ChemicalEntity::MODIF));
+
+      bool withEntities =
+        (mp_calcOptions->monomerEntities() & MONOMER_CHEMENT_MODIF);
 
       // We want a delimited sequence with indication of the
       // different sequence regions for which the composition was
       // determined, thus the true below.
 
-      QString sequence = msp_polymer->getSequenceCstRef().getSequence(
-        m_indexRangeCollection, with_modif_entities, true);
+      QString *sequence =
+        mp_polymer->monomerText(m_coordinateList, withEntities, true);
 
-      *mpa_resultsString += sequence;
+      *mpa_resultsString += *sequence;
 
-      if(with_modif_entities)
+      delete sequence;
+
+      if(withEntities)
         *mpa_resultsString += QObject::tr("Account monomer modifs: yes\n");
       else
         *mpa_resultsString += QObject::tr("Account monomer modifs: no\n");
 
       // Left end and right end modifs
-      with_modif_entities =
-        (static_cast<int>(mref_calcOptions.getPolymerEntities()) &
-           static_cast<int>(
-             libXpertMassCore::Enums::ChemicalEntity::LEFT_END_MODIF) ||
-         static_cast<int>(mref_calcOptions.getPolymerEntities()) &
-           static_cast<int>(
-             libXpertMassCore::Enums::ChemicalEntity::RIGHT_END_MODIF));
+      withEntities =
+        (mp_calcOptions->polymerEntities() & POLYMER_CHEMENT_LEFT_END_MODIF ||
+         mp_calcOptions->polymerEntities() & POLYMER_CHEMENT_RIGHT_END_MODIF);
 
-      if(!with_modif_entities)
+      if(!withEntities)
         {
           *mpa_resultsString += QObject::tr("Account ends' modifs: no\n");
         }
@@ -568,34 +547,28 @@ CompositionsDlg::prepareResultsTxtString(CompositionsTarget target)
           *mpa_resultsString += QObject::tr("Account ends' modifs: yes - ");
 
           // Left end modif
-          with_modif_entities =
-            (static_cast<int>(mref_calcOptions.getPolymerEntities()) &
-             static_cast<int>(
-               libXpertMassCore::Enums::ChemicalEntity::LEFT_END_MODIF));
-          if(with_modif_entities)
+          withEntities = (mp_calcOptions->polymerEntities() &
+                          POLYMER_CHEMENT_LEFT_END_MODIF);
+          if(withEntities)
             {
-              *mpa_resultsString +=
-                QObject::tr("Left end modif: %1 - ")
-                  .arg(msp_polymer->getLeftEndModifCstRef().getName());
+              *mpa_resultsString += QObject::tr("Left end modif: %1 - ")
+                                      .arg(mp_polymer->leftEndModif().name());
             }
 
           // Right end modif
-          with_modif_entities =
-            (static_cast<int>(mref_calcOptions.getPolymerEntities()) &
-             static_cast<int>(
-               libXpertMassCore::Enums::ChemicalEntity::RIGHT_END_MODIF));
-          if(with_modif_entities)
+          withEntities = (mp_calcOptions->polymerEntities() &
+                          POLYMER_CHEMENT_RIGHT_END_MODIF);
+          if(withEntities)
             {
-              *mpa_resultsString +=
-                QObject::tr("Right end modif: %1")
-                  .arg(msp_polymer->getLeftEndModifCstRef().getName());
+              *mpa_resultsString += QObject::tr("Right end modif: %1")
+                                      .arg(mp_polymer->leftEndModif().name());
             }
         }
 
       *mpa_resultsString += QObject::tr("\n\nElemental composition: %1")
                               .arg(m_ui.elementalCompositionLineEdit->text());
     }
-  else if(target == CompositionsTarget::MONOMERIC)
+  else if(target == TARGET_MONOMERIC)
     {
       CompositionTreeViewModel *model = static_cast<CompositionTreeViewModel *>(
         m_ui.compositionTreeView->model());
@@ -675,14 +648,14 @@ CompositionsDlg::exportResultsFile()
   if(!file.open(QIODevice::WriteOnly | QIODevice::Append))
     {
       QMessageBox::information(0,
-                               tr("MassXpert3 - Export Data"),
+                               tr("massXpert - Export Data"),
                                tr("Failed to open file in append mode."),
                                QMessageBox::Ok);
       return false;
     }
 
   QTextStream stream(&file);
-  stream.setEncoding(QStringConverter::Utf8);
+  stream.setCodec("UTF-8");
 
   stream << *mpa_resultsString;
 
@@ -710,6 +683,6 @@ CompositionsDlg::selectResultsFile()
 //////////////////////////////////// The results-exporting functions.
 //////////////////////////////////// The results-exporting functions.
 
-} // namespace MassXpert
+} // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
