@@ -50,7 +50,7 @@
 #include <QLineEdit>
 
 
-namespace MsXpS
+namespace msxps
 {
 
 	namespace massxpert
@@ -65,7 +65,7 @@ class ConfigSettingsDlg : public QDialog
   private:
   Ui::ConfigSettingsDlg m_ui;
 
-  QString m_applicationName;
+  QString m_moduleName;
   ConfigSettings *mp_configSettings;
   QString m_configSettingsFilePath;
 
@@ -85,7 +85,7 @@ class ConfigSettingsDlg : public QDialog
   QWidget *setupNewWidgetry(ConfigSetting *configSetting);
 
   public:
-  ConfigSettingsDlg(const QString &applicationName,
+  ConfigSettingsDlg(const QString &moduleName,
                     ConfigSettings *configSettings,
                     const QString &configSettingsFilePath,
                     bool failedConfig = false);
@@ -105,7 +105,7 @@ class ConfigSettingsDlg : public QDialog
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
 
 #endif // CONFIG_SETTINGS_DLG_HPP
