@@ -1,18 +1,18 @@
 /* BEGIN software license
  *
- * MsXpertSuite - mass spectrometry software suite
+ * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2026 Filippo Rusconi
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
- * This file is part of the MsXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- * The MsXpertSuite project is the successor of the massXpert project. This
+ * The msXpertSuite project is the successor of the massXpert project. This
  * project now includes various independent modules:
  *
- * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
- * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,42 +33,40 @@
 
 /////////////////////// Qt includes
 #include <QMessageBox>
-#include <QSettings>
-
-
-/////////////////////// libXpertMass includes
-#include <MsXpS/libXpertMassCore/PolChemDef.hpp>
-#include <MsXpS/libXpertMassCore/CrossLinker.hpp>
 
 
 /////////////////////// Local includes
 #include "CrossLinkerDefDlg.hpp"
+#include "../nongui/PolChemDef.hpp"
 #include "PolChemDefWnd.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace MassXpert
-{
+	namespace massxpert
+	{
 
 
-CrossLinkerDefDlg::CrossLinkerDefDlg(
-  libXpertMassCore::PolChemDefSPtr pol_chem_def_sp,
-  PolChemDefWnd *pol_chem_def_wnd_p,
-  const QString &settings_file_path,
-  const QString &application_name,
-  const QString &description)
-  : AbstractPolChemDefDependentDlg(pol_chem_def_sp,
-                                   pol_chem_def_wnd_p,
-                                   settings_file_path,
+
+CrossLinkerDefDlg::CrossLinkerDefDlg(PolChemDef *polChemDef,
+                                     PolChemDefWnd *polChemDefWnd,
+                                     const QString &settingsFilePath)
+  : AbstractPolChemDefDependentDlg{polChemDef,
+                                   polChemDefWnd,
+                                   settingsFilePath,
                                    "CrossLinkerDefDlg",
-                                   application_name,
-                                   description),
-    mref_crossLinkers(pol_chem_def_sp->getCrossLinkersRef())
+                                   "massXpert: Crosslinker definition"}
 {
+  mp_list = polChemDef->crossLinkerListPtr();
+
   if(!initialize())
-    qFatal() << "Failed to initialize the dialog window.";
+    qFatal(
+      "Fatal error at %s@%d. Failed to initialize the %s window. Program "
+      "aborted.",
+      __FILE__,
+      __LINE__,
+      m_wndTypeName.toLatin1().data());
 }
 
 
@@ -83,7 +81,7 @@ CrossLinkerDefDlg::closeEvent([[maybe_unused]] QCloseEvent *event)
   // close==destruction. Thus we only hide the dialog remembering its
   // position and size.
 
-  mp_pol_chem_def_wnd_p->m_ui.crossLinkerPushButton->setChecked(false);
+  mp_polChemDefWnd->m_ui.crossLinkerPushButton->setChecked(false);
 
   writeSettings();
 }
@@ -92,7 +90,7 @@ CrossLinkerDefDlg::closeEvent([[maybe_unused]] QCloseEvent *event)
 void
 CrossLinkerDefDlg::readSettings()
 {
-  QSettings settings(m_settings_file_path, QSettings::IniFormat);
+  QSettings settings(m_settingsFilePath, QSettings::IniFormat);
 
   settings.beginGroup(m_wndTypeName);
   restoreGeometry(settings.value("geometry").toByteArray());
@@ -104,7 +102,7 @@ CrossLinkerDefDlg::readSettings()
 void
 CrossLinkerDefDlg::writeSettings()
 {
-  QSettings settings(m_settings_file_path, QSettings::IniFormat);
+  QSettings settings(m_settingsFilePath, QSettings::IniFormat);
 
   settings.beginGroup(m_wndTypeName);
   settings.setValue("geometry", saveGeometry());
@@ -118,16 +116,14 @@ CrossLinkerDefDlg::initialize()
 {
   m_ui.setupUi(this);
 
-  setWindowIcon(qApp->windowIcon());
-
-  // Now we need to actually show the window title (that element is empty in
-  // m_ui)
-  displayWindowTitle();
-
   // Set all the crossLinkers to the list widget.
 
-  for(libXpertMassCore::CrossLinkerSPtr cross_linker_sp : mref_crossLinkers)
-    m_ui.crossLinkerListWidget->addItem(cross_linker_sp->getName());
+  for(int iter = 0; iter < mp_list->size(); ++iter)
+    {
+      CrossLinker *crossLinker = mp_list->at(iter);
+
+      m_ui.crossLinkerListWidget->addItem(crossLinker->name());
+    }
 
   readSettings();
 
@@ -211,8 +207,14 @@ CrossLinkerDefDlg::populateAvailableModifList()
   // is present in the cross-linker.
 
   m_ui.modifNameComboBox->addItem("");
-  for(libXpertMassCore::ModifSPtr modif_sp : msp_polChemDef->getModifsCstRef())
-    m_ui.modifNameComboBox->addItem(modif_sp->getName());
+
+  for(int iter = 0; iter < mp_polChemDef->modifList().size(); ++iter)
+    {
+      Modif *modif = mp_polChemDef->modifList().at(iter);
+      Q_ASSERT(modif);
+
+      m_ui.modifNameComboBox->addItem(modif->name());
+    }
 
   return true;
 }
@@ -227,12 +229,11 @@ CrossLinkerDefDlg::addCrossLinkerPushButtonClicked()
   // Returns -1 if the list is empty.
   int index = m_ui.crossLinkerListWidget->currentRow();
 
-  libXpertMassCore::CrossLinkerSPtr cross_linker_sp =
-    std::make_shared<libXpertMassCore::CrossLinker>(
-      msp_polChemDef, "Type Name", "Type Formula", 0.0, 0.0);
+  CrossLinker *newCrossLinker =
+    new CrossLinker(mp_polChemDef, tr("Type Name"), tr("Type Formula"));
 
-  mref_crossLinkers.insert(mref_crossLinkers.begin() + index, cross_linker_sp);
-  m_ui.crossLinkerListWidget->insertItem(index, cross_linker_sp->getName());
+  mp_list->insert(index, newCrossLinker);
+  m_ui.crossLinkerListWidget->insertItem(index, newCrossLinker->name());
 
   setModified();
 
@@ -243,7 +244,7 @@ CrossLinkerDefDlg::addCrossLinkerPushButtonClicked()
 
   m_ui.crossLinkerListWidget->setCurrentRow(index);
 
-  // Erase cleavageRule data that might be left over by precedent current
+  // Erase cleaveRule data that might be left over by precedent current
   // crossLinker.
   updateModifDetails(0);
 
@@ -268,7 +269,9 @@ CrossLinkerDefDlg::removeCrossLinkerPushButtonClicked()
   QListWidgetItem *item = m_ui.crossLinkerListWidget->takeItem(index);
   delete item;
 
-  mref_crossLinkers.erase(mref_crossLinkers.begin() + index);
+  CrossLinker *crossLinker = mp_list->takeAt(index);
+  Q_ASSERT(crossLinker);
+  delete crossLinker;
 
   setModified();
 
@@ -309,11 +312,11 @@ CrossLinkerDefDlg::moveUpCrossLinkerPushButtonClicked()
   // Get the index of the crossLinker and the crossLinker itself.
   int index = m_ui.crossLinkerListWidget->currentRow();
 
-  auto it = mref_crossLinkers.begin() + index;
   // If the item is already at top of list, do nothing.
-  if(it == mref_crossLinkers.begin())
+  if(!index)
     return;
-  std::iter_swap(it, it - 1); // Swap with the previous element
+
+  mp_list->move(index, index - 1);
 
   QListWidgetItem *item = m_ui.crossLinkerListWidget->takeItem(index);
 
@@ -341,11 +344,11 @@ CrossLinkerDefDlg::moveDownCrossLinkerPushButtonClicked()
   // Get the index of the crossLinker and the crossLinker itself.
   int index = m_ui.crossLinkerListWidget->currentRow();
 
-  auto it = mref_crossLinkers.begin() + index;
   // If the item is already at bottom of list, do nothing.
-  if(it == mref_crossLinkers.end())
+  if(index == m_ui.crossLinkerListWidget->count() - 1)
     return;
-  std::iter_swap(it, it + 1); // Swap with the next element
+
+  mp_list->move(index, index + 1);
 
   QListWidgetItem *item = m_ui.crossLinkerListWidget->takeItem(index);
   m_ui.crossLinkerListWidget->insertItem(index + 1, item);
@@ -368,11 +371,10 @@ CrossLinkerDefDlg::addModifPushButtonClicked()
 
   if(selectedList.size() != 1)
     {
-      QMessageBox::information(
-        this,
-        tr("MassXpert3 - libXpertMassCore::CrossLinker definition"),
-        tr("Please, select a crossLinker first."),
-        QMessageBox::Ok);
+      QMessageBox::information(this,
+                               tr("massXpert - CrossLinker definition"),
+                               tr("Please, select a crossLinker first."),
+                               QMessageBox::Ok);
       return;
     }
 
@@ -381,26 +383,24 @@ CrossLinkerDefDlg::addModifPushButtonClicked()
   int index = m_ui.crossLinkerListWidget->currentRow();
 
   // What's the actual crossLinker?
-  libXpertMassCore::CrossLinkerSPtr cross_linker_sp = mref_crossLinkers.at(index);
+  CrossLinker *crossLinker = mp_list->at(index);
+  Q_ASSERT(crossLinker);
 
   // Allocate the new modif.
-  libXpertMassCore::ModifSPtr modif_sp = std::make_shared<libXpertMassCore::Modif>(
-    msp_polChemDef, "Select modification");
+  Modif *newModif = new Modif(mp_polChemDef, tr("Select modification"));
 
   // Get the row index of the current modif item. Returns -1 if the
   // list is empty.
   index = m_ui.modifListWidget->currentRow();
 
-  m_ui.modifListWidget->insertItem(index, modif_sp->getName());
+  m_ui.modifListWidget->insertItem(index, newModif->name());
 
-  // Needed so that the setCurrentRow() call below actually sets the
+  // Needed so that the setCurrentRow() call below actually set the
   // current row!
   if(index <= 0)
     index = 0;
 
-  std::vector<libXpertMassCore::ModifCstSPtr> modifs =
-    cross_linker_sp->getModifsRef();
-  modifs.insert(modifs.begin() + index, modif_sp);
+  crossLinker->modifList().insert(index, newModif);
 
   m_ui.modifListWidget->setCurrentRow(index);
 
@@ -419,11 +419,13 @@ CrossLinkerDefDlg::removeModifPushButtonClicked()
   if(selectedList.size() != 1)
     return;
 
+
   // Get the index of the current crossLinker so that we know from
   // which crossLinker we'll remove the modif.
   int index = m_ui.crossLinkerListWidget->currentRow();
 
-  libXpertMassCore::CrossLinkerSPtr cross_linker_sp = mref_crossLinkers.at(index);
+  CrossLinker *crossLinker = mp_list->at(index);
+  Q_ASSERT(crossLinker);
 
   // Get the index of the current modif.
   index = m_ui.modifListWidget->currentRow();
@@ -436,9 +438,13 @@ CrossLinkerDefDlg::removeModifPushButtonClicked()
   delete item;
 
   // Remove the modif from the crossLinker proper.
-  std::vector<MsXpS::libXpertMassCore::ModifCstSPtr> modifs =
-    cross_linker_sp->getModifsRef();
-  modifs.erase(modifs.begin() + index);
+
+  QList<Modif *> modifList = crossLinker->modifList();
+
+  Modif *modif = modifList.at(index);
+
+  crossLinker->modifList().removeAt(index);
+  delete modif;
 
   // If there are remaining items, we want to set the next item the
   // currentItem. If not, then, the currentItem should be the one
@@ -478,17 +484,21 @@ CrossLinkerDefDlg::moveUpModifPushButtonClicked()
     return;
 
   // Get the crossLinker to which the modif belongs.
-  int index = m_ui.crossLinkerListWidget->currentRow();
-  libXpertMassCore::CrossLinkerSPtr cross_linker_sp = mref_crossLinkers.at(index);
+  int index                = m_ui.crossLinkerListWidget->currentRow();
+  CrossLinker *crossLinker = mp_list->at(index);
 
   // Get the index of the current modif item.
   index = m_ui.modifListWidget->currentRow();
 
-  auto it = cross_linker_sp->getModifsRef().begin() + index;
   // If the item is already at top of list, do nothing.
-  if(it == cross_linker_sp->getModifsRef().begin())
+  if(!index)
     return;
-  std::iter_swap(it, it - 1);
+
+  // Get the modif itself from the crossLinker.
+  Modif *modif = crossLinker->modifList().at(index);
+
+  crossLinker->modifList().removeAt(index);
+  crossLinker->modifList().insert(index - 1, modif);
 
   QListWidgetItem *item = m_ui.modifListWidget->takeItem(index);
   m_ui.modifListWidget->insertItem(index - 1, item);
@@ -512,17 +522,21 @@ CrossLinkerDefDlg::moveDownModifPushButtonClicked()
     return;
 
   // Get the crossLinker to which the modif belongs.
-  int index = m_ui.crossLinkerListWidget->currentRow();
-  libXpertMassCore::CrossLinkerSPtr cross_linker_sp = mref_crossLinkers.at(index);
+  int index                = m_ui.crossLinkerListWidget->currentRow();
+  CrossLinker *crossLinker = mp_list->at(index);
 
   // Get the index of the current modif item.
   index = m_ui.modifListWidget->currentRow();
 
-  auto it = cross_linker_sp->getModifsRef().begin() + index;
-  // If the item is already at bottom of list, do nothing.
-  if(it == cross_linker_sp->getModifsRef().end())
+  // If the item is already at top of list, do nothing.
+  if(index == m_ui.modifListWidget->count() - 1)
     return;
-  std::iter_swap(it, it + 1);
+
+  // Get the modif itself from the crossLinker.
+  Modif *modif = crossLinker->modifList().at(index);
+
+  crossLinker->modifList().removeAt(index);
+  crossLinker->modifList().insert(index + 1, modif);
 
   QListWidgetItem *item = m_ui.modifListWidget->takeItem(index);
   m_ui.modifListWidget->insertItem(index + 1, item);
@@ -549,12 +563,14 @@ CrossLinkerDefDlg::applyCrossLinkerPushButtonClicked()
   // Get the index of the current crossLinker item.
   int index = m_ui.crossLinkerListWidget->currentRow();
 
-  libXpertMassCore::CrossLinkerSPtr cross_linker_sp = mref_crossLinkers.at(index);
+  CrossLinker *crossLinker = mp_list->at(index);
 
-  // We do not want more than one crossLinker by the same name.
+  // We do not want more than one crossLinker by the same name or the same
+  // symbol.
 
   bool wasEditFormulaEmpty = false;
 
+
   QString editName    = m_ui.nameLineEdit->text();
   QString editFormula = m_ui.formulaLineEdit->text();
   if(editFormula.isEmpty())
@@ -568,20 +584,12 @@ CrossLinkerDefDlg::applyCrossLinkerPushButtonClicked()
   // crossLinker is not the one that is current in the crossLinker list,
   // then we are making a double entry, which is not allowed.
 
-  std::vector<libXpertMassCore::CrossLinkerSPtr>::iterator the_iterator =
-    std::find_if(
-      mref_crossLinkers.begin(),
-      mref_crossLinkers.end(),
-      [editName](const libXpertMassCore::CrossLinkerSPtr iter_cross_linker_sp) {
-        return iter_cross_linker_sp->getName() == editName;
-      });
-
-  if(the_iterator != mref_crossLinkers.end() &&
-     std::distance(mref_crossLinkers.begin(), the_iterator) != index)
+  int nameRes = CrossLinker::isNameInList(editName, *mp_list);
+  if(nameRes != -1 && nameRes != index)
     {
       QMessageBox::warning(this,
-                           tr("MassXpert3 - CrossLinker definition"),
-                           tr("A cross-linker with same name "
+                           tr("massXpert - CrossLinker definition"),
+                           tr("A crossLinker with same name "
                               "exists already."),
                            QMessageBox::Ok);
       return;
@@ -591,41 +599,35 @@ CrossLinkerDefDlg::applyCrossLinkerPushButtonClicked()
   // modification. This is because the name of the crossLinker cannot
   // clash with the name of a modif when setting the graphical
   // vignette of the crossLinker.
-  if(msp_polChemDef->getModifIndexByName(editName) != -1)
+  if(mp_polChemDef->modif(editName))
     {
       QMessageBox::warning(this,
-                           tr("MassXpert3 - CrossLinker definition"),
+                           tr("massXpert - CrossLinker definition"),
                            tr("The name of the cross-linker is already "
                               "used by a modification."),
                            QMessageBox::Ok);
       return;
     }
 
-  libXpertMassCore::Formula formula(editFormula);
+  Formula formula(editFormula);
 
-  libXpertMassCore::IsotopicDataSPtr isotopic_data_sp =
-    msp_polChemDef->getIsotopicDataSPtr();
-
-  libXpertMassCore::ErrorList error_list;
-  if(!formula.validate(isotopic_data_sp, &error_list))
+  if(!formula.validate(mp_polChemDef->atomList()))
     {
       if(wasEditFormulaEmpty)
         {
           QMessageBox::warning(
             this,
-            tr("MassXpert3 - libXpertMassCore::CrossLinker definition"),
+            tr("massXpert - CrossLinker definition"),
             tr("The formula is empty, please enter a formula "
                "like '-H+H' if no reaction is required."),
             QMessageBox::Ok);
         }
       else
         {
-          QMessageBox::warning(
-            this,
-            tr("MassXpert3 - libXpertMassCore::CrossLinker definition"),
-            QString("The formula failed to validate with errors:\n%1\n.")
-              .arg(libXpertMassCore::Utils::joinErrorList(error_list)),
-            QMessageBox::Ok);
+          QMessageBox::warning(this,
+                               tr("massXpert - CrossLinker definition"),
+                               tr("The formula failed to validate."),
+                               QMessageBox::Ok);
         }
 
       return;
@@ -633,13 +635,13 @@ CrossLinkerDefDlg::applyCrossLinkerPushButtonClicked()
 
   // Finally we can update the crossLinker's data:
 
-  cross_linker_sp->setName(editName);
-  cross_linker_sp->setFormula(editFormula);
+  crossLinker->setName(editName);
+  crossLinker->setFormula(editFormula);
 
   // Update the list widget item.
 
   QListWidgetItem *item = m_ui.crossLinkerListWidget->currentItem();
-  item->setData(Qt::DisplayRole, cross_linker_sp->getName());
+  item->setData(Qt::DisplayRole, crossLinker->name());
 
   setModified();
 }
@@ -658,45 +660,38 @@ CrossLinkerDefDlg::applyModifPushButtonClicked()
     return;
 
   // Get the crossLinker to which the modif belongs.
-  int index = m_ui.crossLinkerListWidget->currentRow();
-  libXpertMassCore::CrossLinkerSPtr cross_linker_sp = mref_crossLinkers.at(index);
+  int index                = m_ui.crossLinkerListWidget->currentRow();
+  CrossLinker *crossLinker = mp_list->at(index);
 
   // Get the index of the current modif item.
   index = m_ui.modifListWidget->currentRow();
 
   // Get the modif itself from the crossLinker.
-  libXpertMassCore::ModifCstSPtr modif_csp =
-    cross_linker_sp->getModifsCstRef().at(index);
+  Modif *modif = crossLinker->modifList().at(index);
 
-  QString modif_name = m_ui.modifNameComboBox->currentText();
+  QString modifName = m_ui.modifNameComboBox->currentText();
 
   // Make sure the modification is known to the polymer chemistry
   // definition.
 
-  libXpertMassCore::Modif reference_modif =
-    libXpertMassCore::Modif(msp_polChemDef, "NOT_SET", "NOT_SET");
+  Modif localModif = Modif(mp_polChemDef, "NOT_SET", "NOT_SET");
 
-  libXpertMassCore::ModifCstSPtr reference_modif_csp =
-    msp_polChemDef->getModifCstSPtrByName(modif_name);
-
-  if(reference_modif_csp == nullptr)
+  if(!mp_polChemDef->modif(modifName, &localModif))
     {
       QMessageBox::warning(this,
-                           tr("MassXpert3 - CrossLinker definition"),
+                           tr("massXpert - CrossLinker definition"),
                            tr("The modification is not known to the "
                               "polymer chemistry definition."),
                            QMessageBox::Ok);
       return;
     }
 
-  // Copy the reference modification to the modification that sits inside of the
-  // CrossLinker being defined.
-  modif_csp = reference_modif_csp;
+  modif->mold(localModif);
 
   // Update the list widget item.
 
   QListWidgetItem *item = m_ui.modifListWidget->currentItem();
-  item->setData(Qt::DisplayRole, modif_csp->getName());
+  item->setData(Qt::DisplayRole, modif->name());
 
   setModified();
 }
@@ -712,65 +707,58 @@ CrossLinkerDefDlg::validatePushButtonClicked()
   // everything is fine and that colinearity is perfect between the
   // crossLinker list and the listwidget.
 
-  std::size_t item_count = m_ui.crossLinkerListWidget->count();
+  int itemCount = m_ui.crossLinkerListWidget->count();
 
-  if(item_count != mref_crossLinkers.size())
+  if(itemCount != mp_list->size())
     {
       errorList << QString(
-        tr("\nThe number of cross-linkers in the "
+        tr("\nThe number of crossLinkers in the "
            "list widget \n"
-           "and in the list of cross-linkers "
+           "and in the list of crossLinkers "
            "is not identical.\n"));
 
       QMessageBox::warning(this,
-                           tr("MassXpert3 - CrossLinker definition"),
+                           tr("massXpert - CrossLinker definition"),
                            errorList.join("\n"),
                            QMessageBox::Ok);
       return false;
     }
 
-  for(std::size_t iter = 0; iter < mref_crossLinkers.size(); ++iter)
+  for(int iter = 0; iter < mp_list->size(); ++iter)
     {
       QListWidgetItem *item = m_ui.crossLinkerListWidget->item(iter);
 
-      libXpertMassCore::CrossLinkerSPtr cross_linker_sp =
-        mref_crossLinkers.at(iter);
+      CrossLinker *crossLinker = mp_list->at(iter);
 
-      if(item->text() != cross_linker_sp->getName())
+      if(item->text() != crossLinker->name())
         errorList << QString(tr("\nCrossLinker at index %1 has not the same\n"
                                 "name as the list widget item at the\n"
                                 "same index.\n")
                                .arg(iter));
 
-      MsXpS::libXpertMassCore::ErrorList error_list;
-
-      if(!cross_linker_sp->validate(&error_list))
-        errorList
-          << QString(
-               "\nCrossLinker at index %1 failed "
-               "to validate.\n"
-               "Errors: %2\n\nPlease, make sure that there are either no"
-               " or at least two modifications for the cross-link.\n")
-               .arg(iter)
-               .arg(libXpertMassCore::Utils::joinErrorList(error_list));
+      if(!crossLinker->validate())
+        errorList << QString(
+          tr("\nCrossLinker at index %1 failed "
+             "to validate.\n"
+             "Please, make sure that there are either no"
+             " or at least two modifications for the cross-link.\n")
+            .arg(iter));
     }
 
   if(errorList.size())
     {
-      QMessageBox::warning(
-        this,
-        tr("MassXpert3 - libXpertMassCore::CrossLinker definition"),
-        errorList.join("\n"),
-        QMessageBox::Ok);
+      QMessageBox::warning(this,
+                           tr("massXpert - CrossLinker definition"),
+                           errorList.join("\n"),
+                           QMessageBox::Ok);
       return false;
     }
   else
     {
-      QMessageBox::warning(
-        this,
-        tr("MassXpert3 - libXpertMassCore::CrossLinker definition"),
-        ("Validation: success\n"),
-        QMessageBox::Ok);
+      QMessageBox::warning(this,
+                           tr("massXpert - CrossLinker definition"),
+                           ("Validation: success\n"),
+                           QMessageBox::Ok);
     }
 
   return true;
@@ -794,16 +782,21 @@ CrossLinkerDefDlg::crossLinkerListWidgetItemSelectionChanged()
   // Get the index of the current crossLinker.
   int index = m_ui.crossLinkerListWidget->currentRow();
 
-  libXpertMassCore::CrossLinkerSPtr cross_linker_sp = mref_crossLinkers.at(index);
+  CrossLinker *crossLinker = mp_list->at(index);
+  Q_ASSERT(crossLinker);
 
   // Set the data of the crossLinker to their respective widgets.
-  updateCrossLinkerIdentityDetails(cross_linker_sp);
+  updateCrossLinkerIdentityDetails(crossLinker);
 
   // The list of modifs
   m_ui.modifListWidget->clear();
 
-  for(libXpertMassCore::ModifCstSPtr modif_csp : cross_linker_sp->getModifsCstRef())
-    m_ui.modifListWidget->addItem(modif_csp->getName());
+  for(int iter = 0; iter < crossLinker->modifList().size(); ++iter)
+    {
+      Modif *modif = crossLinker->modifList().at(iter);
+
+      m_ui.modifListWidget->addItem(modif->name());
+    }
 
   if(!m_ui.modifListWidget->count())
     updateModifDetails(0);
@@ -831,29 +824,29 @@ CrossLinkerDefDlg::modifListWidgetItemSelectionChanged()
   int index = m_ui.crossLinkerListWidget->currentRow();
 
   // Find the modif object in the list of modifs.
-  libXpertMassCore::CrossLinkerSPtr cross_linker_sp = mref_crossLinkers.at(index);
+  CrossLinker *crossLinker = mp_list->at(index);
+  Q_ASSERT(crossLinker);
 
   // Get the index of the current modif.
   index = m_ui.modifListWidget->currentRow();
 
   // Get the modif that is currently selected from the crossLinker's list
   // of modifs.
-  libXpertMassCore::ModifCstSPtr modif_csp =
-    cross_linker_sp->getModifsCstRef().at(index);
+  Modif *modif = crossLinker->modifList().at(index);
+  Q_ASSERT(modif);
 
   // Set the data of the modif to their respective widgets.
-  updateModifDetails(modif_csp);
+  updateModifDetails(modif);
 }
 
 
 void
-CrossLinkerDefDlg::updateCrossLinkerIdentityDetails(
-  libXpertMassCore::CrossLinkerSPtr cross_link_sp)
+CrossLinkerDefDlg::updateCrossLinkerIdentityDetails(CrossLinker *crossLinker)
 {
-  if(cross_link_sp != nullptr)
+  if(crossLinker)
     {
-      m_ui.nameLineEdit->setText(cross_link_sp->getName());
-      m_ui.formulaLineEdit->setText(cross_link_sp->getFormula());
+      m_ui.nameLineEdit->setText(crossLinker->name());
+      m_ui.formulaLineEdit->setText(crossLinker->formula());
     }
   else
     {
@@ -864,11 +857,11 @@ CrossLinkerDefDlg::updateCrossLinkerIdentityDetails(
 
 
 void
-CrossLinkerDefDlg::updateModifDetails(libXpertMassCore::ModifCstSPtr modif_csp)
+CrossLinkerDefDlg::updateModifDetails(Modif *modif)
 {
-  if(modif_csp != nullptr)
+  if(modif)
     {
-      int index = m_ui.modifNameComboBox->findText(modif_csp->getName());
+      int index = m_ui.modifNameComboBox->findText(modif->name());
 
       // The name might be tr("Select modif") if the modif was just
       // created(see the function to add a modif to a
@@ -906,6 +899,6 @@ CrossLinkerDefDlg::validate()
   return validatePushButtonClicked();
 }
 
-} // namespace MassXpert
+} // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
