@@ -1,18 +1,18 @@
 /* BEGIN software license
  *
- * MsXpertSuite - mass spectrometry software suite
+ * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2026 Filippo Rusconi
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
- * This file is part of the MsXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- * The MsXpertSuite project is the successor of the massXpert project. This
+ * The msXpertSuite project is the successor of the massXpert project. This
  * project now includes various independent modules:
  *
- * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
- * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,11 +39,12 @@
 #include <QSortFilterProxyModel>
 
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace MassXpert
-{
+	namespace massxpert
+	{
+
 
 
 class FragmentOligomerTableViewSortProxyModel : public QSortFilterProxyModel
@@ -54,11 +55,11 @@ class FragmentOligomerTableViewSortProxyModel : public QSortFilterProxyModel
 
   QString m_patternFilter;
 
-  double m_monoFilter = 0;
-  double m_avgFilter  = 0;
-  double m_tolerance  = 0;
+  double m_monoFilter;
+  double m_avgFilter;
+  double m_tolerance;
 
-  int m_chargeFilter = 0;
+  int m_chargeFilter;
 
   protected:
   bool lessThan(const QModelIndex &, const QModelIndex &) const;
@@ -80,9 +81,9 @@ class FragmentOligomerTableViewSortProxyModel : public QSortFilterProxyModel
   void applyNewFilter();
 };
 
-} // namespace MassXpert
+} // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
 
 #endif // FRAGMENT_OLIGOMER_TABLE_VIEW_SORT_PROXY_MODEL_HPP
