@@ -44,8 +44,6 @@
 #include <QList>
 #include <QApplication>
 #include <QDebug>
-#include <libXpertMass/PolChemDef.hpp>
-#include <libXpertMass/PolChemDefEntity.hpp>
 
 
 /////////////////////// Local includes
@@ -55,7 +53,7 @@
 
 #include "MainWindow.hpp"
 
-#include <libXpertMass/PolChemDefSpec.hpp>
+#include "../nongui/PolChemDefSpec.hpp"
 #include "../nongui/PolChemDefCatParser.hpp"
 
 #include "ConfigSettingsDlg.hpp"
@@ -69,7 +67,7 @@
 #include "../nongui/ConfigSetting.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
 namespace massxpert
@@ -1070,21 +1068,19 @@ namespace massxpert
 
     settings.beginGroup("decimalPlacesOptions");
 
-    libXpertMass::ATOM_DEC_PLACES = settings.value("ATOM_DEC_PLACES", 10).toInt();
+    ATOM_DEC_PLACES = settings.value("ATOM_DEC_PLACES", 10).toInt();
     // qDebug() << __FILE__ << __LINE__
     // << "ATOM_DEC_PLACES" << ATOM_DEC_PLACES;
 
-    libXpertMass::OLIGOMER_DEC_PLACES =
-      settings.value("OLIGOMER_DEC_PLACES", 5).toInt();
+    OLIGOMER_DEC_PLACES = settings.value("OLIGOMER_DEC_PLACES", 5).toInt();
     // qDebug() << __FILE__ << __LINE__
     // << "OLIGOMER_DEC_PLACES" << OLIGOMER_DEC_PLACES;
 
-    libXpertMass::POLYMER_DEC_PLACES =
-      settings.value("POLYMER_DEC_PLACES", 3).toInt();
+    POLYMER_DEC_PLACES = settings.value("POLYMER_DEC_PLACES", 3).toInt();
     // qDebug() << __FILE__ << __LINE__
     // << "POLYMER_DEC_PLACES" << POLYMER_DEC_PLACES;
 
-    libXpertMass::PH_PKA_DEC_PLACES = settings.value("PH_PKA_DEC_PLACES", 2).toInt();
+    PH_PKA_DEC_PLACES = settings.value("PH_PKA_DEC_PLACES", 2).toInt();
     // qDebug() << __FILE__ << __LINE__
     // << "PH_PKA_DEC_PLACES" << PH_PKA_DEC_PLACES;
 
@@ -1100,24 +1096,24 @@ namespace massxpert
   }
 
 
-  QList<libXpertMass::PolChemDefSpec *> *
+  QList<PolChemDefSpec *> *
   MainWindow::polChemDefCatList()
   {
     return &m_polChemDefCatList;
   }
 
 
-  std::vector<libXpertMass::PolChemDefCstSPtr>
+  QList<PolChemDef *> *
   MainWindow::polChemDefList()
   {
-    return m_polChemDefList;
+    return &m_polChemDefList;
   }
 
 
-  libXpertMass::PolChemDefSpec *
+  PolChemDefSpec *
   MainWindow::polChemDefSpecName(const QString &name)
   {
-    libXpertMass::PolChemDefSpec *polChemDefSpec = 0;
+    PolChemDefSpec *polChemDefSpec = 0;
 
     for(int iter = 0; iter < m_polChemDefCatList.size(); ++iter)
       {
@@ -1131,10 +1127,10 @@ namespace massxpert
   }
 
 
-  libXpertMass::PolChemDefSpec *
+  PolChemDefSpec *
   MainWindow::polChemDefSpecFilePath(const QString &filePath)
   {
-    libXpertMass::PolChemDefSpec *polChemDefSpec = 0;
+    PolChemDefSpec *polChemDefSpec = 0;
 
     for(int iter = 0; iter < m_polChemDefCatList.size(); ++iter)
       {
@@ -1148,29 +1144,30 @@ namespace massxpert
   }
 
 
-  libXpertMass::PolChemDefCstSPtr
-  MainWindow::polChemDefByName(const QString &name)
+  PolChemDef *
+  MainWindow::polChemDefName(const QString &name)
   {
-    libXpertMass::PolChemDefCstSPtr polChemDefCstSPtr;
+    PolChemDef *polChemDef = 0;
 
-    std::vector<libXpertMass::PolChemDefCstSPtr>::iterator it =
-      find_if(m_polChemDefList.begin(),
-              m_polChemDefList.end(),
-              [name](libXpertMass::PolChemDefCstSPtr pcdsp) {
-                return pcdsp->name() == name;
-              });
+    for(int iter = 0; iter < m_polChemDefList.size(); ++iter)
+      {
+        polChemDef = m_polChemDefList.at(iter);
 
-    if(it != m_polChemDefList.end())
-      return *it;
+        // qDebug() << __FILE__ << __LINE__
+        // << "iterated polChemDef:" << polChemDef->name();
 
-    return nullptr;
+        if(polChemDef->name() == name)
+          return polChemDef;
+      }
+
+    return 0;
   }
 
 
   void
   MainWindow::polChemDefCatStringList(QStringList &stringList)
   {
-    libXpertMass::PolChemDefSpec *polChemDefSpec = 0;
+    PolChemDefSpec *polChemDefSpec = 0;
 
     for(int iter = 0; iter < m_polChemDefCatList.size(); ++iter)
       {
@@ -1799,4 +1796,4 @@ namespace massxpert
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
