@@ -1,18 +1,18 @@
 /* BEGIN software license
  *
- * MsXpertSuite - mass spectrometry software suite
+ * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2026 Filippo Rusconi
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
- * This file is part of the MsXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- * The MsXpertSuite project is the successor of the massXpert project. This
+ * The msXpertSuite project is the successor of the massXpert project. This
  * project now includes various independent modules:
  *
- * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
- * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,7 +37,6 @@
 #include <QMessageBox>
 #include <QApplication>
 #include <QDrag>
-#include <QMenu>
 
 
 /////////////////////// Local includes
@@ -45,18 +44,19 @@
 #include "MassSearchOligomerTableView.hpp"
 #include "MassSearchOligomerTableViewSortProxyModel.hpp"
 
-#include <MsXpS/libXpertMassCore/Oligomer.hpp>
+#include "../nongui/Oligomer.hpp"
 
 #include "MassSearchDlg.hpp"
 
 #include "MassSearchOligomerTableViewMimeData.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace MassXpert
-{
+	namespace massxpert
+	{
+
 
 
 MassSearchOligomerTableView::MassSearchOligomerTableView(QWidget *parent)
@@ -106,17 +106,16 @@ MassSearchOligomerTableView::~MassSearchOligomerTableView()
 
 
 void
-MassSearchOligomerTableView::setOligomerCollection(
-  libXpertMassCore::OligomerCollection *oligomerList)
+MassSearchOligomerTableView::setOligomerList(OligomerList *oligomerList)
 {
-  mp_oligomers = oligomerList;
+  mp_oligomerList = oligomerList;
 }
 
 
-const libXpertMassCore::OligomerCollection *
+const OligomerList *
 MassSearchOligomerTableView::oligomerList()
 {
-  return mp_oligomers;
+  return mp_oligomerList;
 }
 
 
@@ -134,24 +133,27 @@ MassSearchOligomerTableView::parentDlg()
   return mp_parentDlg;
 }
 
-// The newly added oligomers are added at index in the OligomerCollection
-// passed as parameter.
 int
-MassSearchOligomerTableView::selectedOligomers(
-  libXpertMassCore::OligomerCollection *oligomers_p, std::size_t index) const
+MassSearchOligomerTableView::selectedOligomers(OligomerList *oligomerList,
+                                               int index) const
 {
-  if(oligomers_p == nullptr)
-    qFatal() << "Programming error.";
+  if(!oligomerList)
+    qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
 
   int count = 0;
 
-  std::size_t local_index = 0;
+  int localIndex = 0;
 
   // How many oligomers are there in the list passed as argument?
-  std::size_t oligomer_count = oligomers_p->size();
+  int oligomerCount = oligomerList->size();
 
-  if(index > oligomer_count)
-    qFatal() << "Programming error.";
+  if(index > oligomerCount)
+    qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
+
+  // If index is -1 , then we are asked to append the oligomers to
+  // the list.
+  if(index == -1)
+    localIndex = oligomerList->size();
 
   // We first have to get the selection model for the proxy model.
 
@@ -199,41 +201,22 @@ MassSearchOligomerTableView::selectedOligomers(
       else
         processedRowList.append(row);
 
-      libXpertMassCore::OligomerSPtr oligomer_sp =
-        mp_oligomers->getOligomersCstRef().at(row);
+      Oligomer *oligomer = mp_oligomerList->at(row);
 
-      libXpertMassCore::OligomerSPtr new_oligomer_sp =
-        std::make_shared<libXpertMassCore::Oligomer>(*oligomer_sp);
-
-#ifdef QT_DEBUG
-      // Sanity check:
-      libXpertMassCore::Prop *the_prop = oligomer_sp->prop("SEARCHED_MZ");
-      Q_ASSERT(the_prop);
-      double mzSearchedDouble = *static_cast<const double *>(the_prop->data());
-      qDebug() << "The searched m/z:" << mzSearchedDouble;
-
-      // Sanity check:
-      libXpertMassCore::Prop *the_other_prop = new_oligomer_sp->prop("SEARCHED_MZ");
-      Q_ASSERT(the_other_prop);
-      mzSearchedDouble = *static_cast<const double *>(the_other_prop->data());
-      qDebug() << "The other searched m/z:" << mzSearchedDouble;
-#endif
+      Oligomer *newOligomer = new Oligomer(*oligomer);
 
       // Create a NoDeletePointerProp, which might be used later by
       // the user of the list of oligomers to highlight regions in
       // the sequence editor.
 
-      libXpertMassCore::NoDeletePointerProp *prop =
-        new libXpertMassCore::NoDeletePointerProp(
-          "SEQUENCE_EDITOR_WND",
-          static_cast<void *>(mp_parentDlg->editorWnd()));
+      NoDeletePointerProp *prop = new NoDeletePointerProp(
+        "SEQUENCE_EDITOR_WND", static_cast<void *>(mp_parentDlg->editorWnd()));
 
-      new_oligomer_sp->appendProp(prop);
+      newOligomer->appendProp(prop);
 
-      oligomers_p->getOligomersRef().insert(
-        oligomers_p->getOligomersRef().begin() + local_index, new_oligomer_sp);
+      oligomerList->insert(localIndex, newOligomer);
 
-      ++local_index;
+      ++localIndex;
       ++count;
     }
 
@@ -242,158 +225,119 @@ MassSearchOligomerTableView::selectedOligomers(
 
 
 QString *
-MassSearchOligomerTableView::describeSelectedOligomersAsPlainText(
+MassSearchOligomerTableView::selectedOligomersAsPlainText(
   QString delimiter,
   bool withSequence,
   bool forXpertMiner,
-  libXpertMassCore::Enums::MassType massType) const
+  MassType massType) const
 {
   // Let's get all the currently selected oligomers in one list.
 
-  libXpertMassCore::OligomerCollection selected_oligomers;
+  OligomerList oligomerList;
 
-  // The selected oligomers are *allocated* into the selected_oligomers
-  // OligomerCollection. These oligomers are inserted at index 0 below (which
-  // is like appending, since the collection is empty).
-
-  // As we use them below,  we'll free them by simply erasing them from the
-  // container.
-  std::size_t selected_oligomer_count =
-    selectedOligomers(&selected_oligomers, /* insertion index*/ 0);
+  // Append the selected oligomers to the empty list.
+  int appendedOligomerCount = selectedOligomers(&oligomerList, -1);
 
   // Sanity check
-  if(selected_oligomer_count != selected_oligomers.size())
+  if(appendedOligomerCount != oligomerList.size())
     qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
 
   // Allocate a string in which we describe all the selected items.
 
   QString *text = new QString();
 
+
   // For export to XpertMiner, we only want the masses asked for:
-  // libXpertMassCore::Enums::MassType::MONO or MASS_AVG. Also, we want the format
-  // to be :
+  // MassType::MASS_MONO or MASS_AVG. Also, we want the format to be :
 
   // mass <delim> charge <delim> name <delim> coords
 
-  // When exporting for clipboard or file:
-
-  // clang-format off
-  // Searched:  searched mass $ found mono $ found avg $ charge $ name $ index_range $ isModified $
-  // Searched: 827.34700 $ 827.34654 $ 828.05672 $ 1 $ 827.347-z1#1 $ [1-8] $ 0 $
-  // MAMISGMS
-  // clang-format on
-
   if(!forXpertMiner)
     {
       // The header of the column set output only if the data are
       // not for XpertMiner.
-      *text += QString(
-                 "\nSearched mass%1Found Mono%1Found Avg%1Charge%1Name%1Index "
-                 "Range%1isModified?\n\n")
-                 .arg(delimiter);
+      *text += QObject::tr(
+        "\nSearched mass \t : Name \t :"
+        "Coordinates \t : Error \t :"
+        "Mono \t : Avg \t : Modif\n\n");
     }
 
-  std::vector<libXpertMassCore::OligomerSPtr>::iterator the_iterator =
-    selected_oligomers.getOligomersRef().begin();
-  std::vector<libXpertMassCore::OligomerSPtr>::iterator the_end_iterator =
-    selected_oligomers.getOligomersRef().end();
-
-  while(the_iterator != the_end_iterator)
+  while(!oligomerList.isEmpty())
     {
-      // Get the searched mz out of the libXpertMassCore::Prop object.
+      Oligomer *oligomer = oligomerList.takeFirst();
 
-      libXpertMassCore::Prop *prop = (*the_iterator)->prop("SEARCHED_MZ");
+      // Get the searched mz out of the Prop object.
+
+      Prop *prop = oligomer->prop("SEARCHED_MZ");
       Q_ASSERT(prop);
 
       double mzSearchedDouble = *static_cast<const double *>(prop->data());
 
-      QString mzSearchedString;
-      mzSearchedString.setNum(
-        mzSearchedDouble, 'f', libXpertMassCore::OLIGOMER_DEC_PLACES);
+      QString mzSearched;
+      mzSearched.setNum(mzSearchedDouble, 'f', OLIGOMER_DEC_PLACES);
 
-      prop = nullptr;
-      prop = (*the_iterator)->prop("ERROR_MZ");
+      prop = 0;
+      prop = oligomer->prop("ERROR_MZ");
       Q_ASSERT(prop);
 
       double mzErrorDouble = *static_cast<const double *>(prop->data());
 
-      QString mzErrorString;
-      mzErrorString.setNum(
-        mzErrorDouble, 'f', libXpertMassCore::OLIGOMER_DEC_PLACES);
-
-      // Searched: 827.34700 $ 827.34654 $ 828.05672 $ 1 $ 827.347-z1#1 $ [1-8]
-      // $ 0 $ MAMISGMS
+      QString mzError;
+      mzError.setNum(mzErrorDouble, 'f', OLIGOMER_DEC_PLACES);
 
       if(!forXpertMiner)
-        *text += QString("\n%1%2").arg(mzSearchedString).arg(delimiter);
+        *text += QString("\nSearched: %1%2").arg(mzSearched).arg(delimiter);
 
-      if(forXpertMiner && massType == libXpertMassCore::Enums::MassType::AVG)
+      if(forXpertMiner && massType == MassType::MASS_AVG)
         {
         }
       else
         {
-          *text +=
-            QString("%1%2")
-              .arg(
-                (*the_iterator)->getMass(libXpertMassCore::Enums::MassType::MONO),
-                0,
-                'f',
-                libXpertMassCore::OLIGOMER_DEC_PLACES)
-              .arg(delimiter);
+          *text += QString("%1%2")
+                     .arg(oligomer->monoString(OLIGOMER_DEC_PLACES))
+                     .arg(delimiter);
         }
 
-      if(forXpertMiner && massType == libXpertMassCore::Enums::MassType::MONO)
+      if(forXpertMiner && massType == MassType::MASS_MONO)
         {
         }
       else
         {
-          *text +=
-            QString("%1%2")
-              .arg((*the_iterator)->getMass(libXpertMassCore::Enums::MassType::AVG),
-                   0,
-                   'f',
-                   libXpertMassCore::OLIGOMER_DEC_PLACES)
-              .arg(delimiter);
+          *text += QString("%1%2")
+                     .arg(oligomer->avgString(OLIGOMER_DEC_PLACES))
+                     .arg(delimiter);
         }
 
-      *text += QString("%1%2")
-                 .arg((*the_iterator)->getIonizerCstRef().charge())
-                 .arg(delimiter);
+      *text += QString("%1%2").arg(oligomer->charge()).arg(delimiter);
 
-      *text += QString("%1%2").arg((*the_iterator)->getName()).arg(delimiter);
+      *text += QString("%1%2").arg(oligomer->name()).arg(delimiter);
 
       *text +=
         QString("%1%2")
-          .arg(
-            (*the_iterator)->getIndexRangeCollectionCstRef().positionsAsText())
+          .arg(static_cast<CoordinateList *>(oligomer)->positionsAsText())
           .arg(delimiter);
 
       if(!forXpertMiner)
-        *text +=
-          QString("%1%2").arg((*the_iterator)->isModified()).arg(delimiter);
+        *text += QString("%1%2").arg(oligomer->isModified()).arg(delimiter);
 
       // We cannot export the sequence if data are for XpertMiner
       if(!forXpertMiner && withSequence)
         {
-          QString sequence =
-            (*the_iterator)
-              ->getPolymerCstSPtr()
-              ->getSequenceCstRef()
-              .getSequence((*the_iterator)->getIndexRangeCollectionCstRef());
+          QString *sequence = oligomer->monomerText();
 
-          *text += QString("\n%1").arg(sequence);
+          *text += QString("\n%1").arg(*sequence);
+
+          delete sequence;
         }
 
       // Terminate the stanza
       *text += QString("\n");
 
-      ++the_iterator;
+      // We can now delete the allocated oligomer, since we do not
+      // need it anymore.
+      delete oligomer;
     }
 
-  // We can now delete all the allocated oligomers, since we do not
-  // need them anymore.
-  selected_oligomers.getOligomersRef().clear();
-
   // Terminate the string with a new line.
   *text += QString("\n");
 
@@ -410,7 +354,7 @@ MassSearchOligomerTableView::mousePressEvent(QMouseEvent *mouseEvent)
     }
   else if(mouseEvent->buttons() & Qt::RightButton)
     {
-      contextMenu->popup(mouseEvent->globalPosition().toPoint());
+      contextMenu->popup(mouseEvent->globalPos());
       return;
     }
 
@@ -468,29 +412,18 @@ MassSearchOligomerTableView::currentChanged(const QModelIndex &current,
   // tableView (that list actually belongs to the MassSearchDlg
   // instance.
 
-  libXpertMassCore::OligomerSPtr oligomer_sp =
-    mp_oligomers->getOligomersCstRef().at(row);
+  Oligomer *oligomer = mp_oligomerList->at(row);
 
   // If the oligomers obtained with the cleavage are old and the
   // sequence has been changed since the cleavage, then the
   // oligomers might point to a sequence element that is no more. We
   // want to avoid such kind of errors.
 
-  libXpertMassCore::IndexRange *index_range_p =
-    oligomer_sp->getCalcOptionsCstRef()
-      .getIndexRangeCollectionCstRef()
-      .mostInclusiveLeftRightIndexRange();
-
-  qsizetype start_index = index_range_p->m_start;
-  qsizetype stop_index  = index_range_p->m_stop;
-
-  delete index_range_p;
-
-  if(start_index >= (qsizetype)oligomer_sp->getPolymerCstSPtr()->size() ||
-     stop_index >= (qsizetype)oligomer_sp->getPolymerCstSPtr()->size())
+  if(oligomer->startIndex() >= oligomer->polymer()->size() ||
+     oligomer->endIndex() >= oligomer->polymer()->size())
     {
       QMessageBox::warning(this,
-                           tr("MassXpert3 - Mass Search"),
+                           tr("massXpert - Mass Search"),
                            tr("%1@%2\n"
                               "The monomer indices do not correspond "
                               "to a valid polymer sequence range.\n"
@@ -503,7 +436,6 @@ MassSearchOligomerTableView::currentChanged(const QModelIndex &current,
       return;
     }
 
-
   // Old version, check if it needs to be so, or if the version
   // below is fine.
 
@@ -511,17 +443,18 @@ MassSearchOligomerTableView::currentChanged(const QModelIndex &current,
   //   oligomer->polymer()->monomerText(oligomer->startIndex(),
   //                                    oligomer->endIndex(), true);
 
-  QString text =
-    oligomer_sp->getPolymerCstSPtr()->getSequenceCstRef().getSequence();
+  QString *text = oligomer->monomerText();
 
   // We are getting text for an oligomer; it cannot be empty,
   // because that would mean the oligomer has no monomers. In that
   // case it is not conceivable that the oligomer be in the mass
   // search product list.
 
-  Q_ASSERT(!text.isEmpty());
+  Q_ASSERT(!text->isEmpty());
 
-  mp_parentDlg->updateOligomerSequence(&text);
+  mp_parentDlg->updateOligomerSequence(text);
+
+  delete text;
 
   QTableView::currentChanged(sourceIndex, previous);
 }
@@ -544,22 +477,13 @@ MassSearchOligomerTableView::itemActivated(const QModelIndex &index)
   // tableView (that list actually belongs to the CleavageDlg
   // instance.
 
-  libXpertMassCore::OligomerSPtr oligomer_sp =
-    mp_oligomers->getOligomersCstRef().at(row);
+  Oligomer *oligomer = mp_oligomerList->at(row);
 
-  libXpertMassCore::IndexRange *index_range_p =
-    oligomer_sp->getCalcOptionsCstRef()
-      .getIndexRangeCollectionCstRef()
-      .mostInclusiveLeftRightIndexRange();
-
-  qsizetype start_index = index_range_p->m_start;
-  qsizetype stop_index  = index_range_p->m_stop;
-
-  if(start_index >= (qsizetype)oligomer_sp->getPolymerCstSPtr()->size() ||
-     stop_index >= (qsizetype)oligomer_sp->getPolymerCstSPtr()->size())
+  if(oligomer->startIndex() >= oligomer->polymer()->size() ||
+     oligomer->endIndex() >= oligomer->polymer()->size())
     {
       QMessageBox::warning(this,
-                           tr("MassXpert3 - Mass Search"),
+                           tr("massXpert - Mass Search"),
                            tr("%1@%2\n"
                               "The monomer indices do not correspond "
                               "to a valid polymer sequence range.\n"
@@ -577,9 +501,8 @@ MassSearchOligomerTableView::itemActivated(const QModelIndex &index)
   // Remove the previous selection, so that we can start fresh.
   editorWnd->mpa_editorGraphicsView->resetSelection();
 
-  editorWnd->mpa_editorGraphicsView->setSelection(*index_range_p, false, false);
-
-  delete index_range_p;
+  editorWnd->mpa_editorGraphicsView->setSelection(
+    oligomer->startIndex(), oligomer->endIndex(), false, false);
 }
 
 
@@ -588,25 +511,21 @@ MassSearchOligomerTableView::itemActivated(const QModelIndex &index)
 void
 MassSearchOligomerTableView::copyMono()
 {
-  return copyMassList(libXpertMassCore::Enums::MassType::MONO);
+  return copyMassList(MassType::MASS_MONO);
 }
 
 
 void
 MassSearchOligomerTableView::copyAvg()
 {
-  return copyMassList(libXpertMassCore::Enums::MassType::AVG);
+  return copyMassList(MassType::MASS_AVG);
 }
 
 
 void
-MassSearchOligomerTableView::copyMassList(
-  libXpertMassCore::Enums::MassType mass_type)
+MassSearchOligomerTableView::copyMassList(int monoOrAvg)
 {
-  if(mass_type == libXpertMassCore::Enums::MassType::BOTH)
-    qFatal() << "Programming error.";
-
-  QString text;
+  QString massList;
 
 
   // We want to prepare a textual list of masses (either MONO or
@@ -632,34 +551,27 @@ MassSearchOligomerTableView::copyMassList(
       // qDebug() << __FILE__ << __LINE__
       //          << "sourceRow:" << sourceRow;
 
-      libXpertMassCore::OligomerSPtr oligomer_sp =
-        mp_oligomers->getOligomersCstRef().at(sourceRow);
+      Oligomer *oligomer = mp_oligomerList->at(sourceRow);
 
-      if(mass_type == libXpertMassCore::Enums::MassType::MONO)
-        text += QString::number(
-          oligomer_sp->getMass(libXpertMassCore::Enums::MassType::MONO),
-          'f',
-          libXpertMassCore::OLIGOMER_DEC_PLACES);
-      else if(mass_type == libXpertMassCore::Enums::MassType::AVG)
-        text += QString::number(
-          oligomer_sp->getMass(libXpertMassCore::Enums::MassType::AVG),
-          'f',
-          libXpertMassCore::OLIGOMER_DEC_PLACES);
+      if(monoOrAvg == MassType::MASS_MONO)
+        massList += oligomer->monoString(OLIGOMER_DEC_PLACES);
+      else if(monoOrAvg == MassType::MASS_AVG)
+        massList += oligomer->avgString(OLIGOMER_DEC_PLACES);
       else
-        qFatal() << "Programming error.";
+        qFatal("Fatal error at %s@%d. Aborting.", __FILE__, __LINE__);
 
       // End the mass item with a new line.
-      text += "\n";
+      massList += "\n";
     }
 
-  if(text.isEmpty())
+  if(massList.isEmpty())
     return;
 
   QClipboard *clipboard = QApplication::clipboard();
 
-  clipboard->setText(text, QClipboard::Clipboard);
+  clipboard->setText(massList, QClipboard::Clipboard);
 }
 
-} // namespace MassXpert
+} // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
