@@ -1,18 +1,18 @@
 /* BEGIN software license
  *
- * MsXpertSuite - mass spectrometry software suite
+ * msXpertSuite - mass spectrometry software suite
  * -----------------------------------------------
- * Copyright(C) 2009,...,2026 Filippo Rusconi
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
  * http://www.msxpertsuite.org
  *
- * This file is part of the MsXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- * The MsXpertSuite project is the successor of the massXpert project. This
+ * The msXpertSuite project is the successor of the massXpert project. This
  * project now includes various independent modules:
  *
- * - MassXpert, model polymer chemistries and simulate mass spectrometric data;
- * - MineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,41 +33,40 @@
 
 /////////////////////// Qt includes
 #include <QMessageBox>
-#include <QSettings>
-
-
-/////////////////////// libXpertMass includes
-#include <MsXpS/libXpertMassCore/PolChemDef.hpp>
-#include <MsXpS/libXpertMassCore/Monomer.hpp>
 
 
 /////////////////////// Local includes
 #include "MonomerDefDlg.hpp"
+#include "../nongui/PolChemDef.hpp"
 #include "PolChemDefWnd.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace MassXpert
-{
+	namespace massxpert
+	{
 
 
-MonomerDefDlg::MonomerDefDlg(libXpertMassCore::PolChemDefSPtr pol_chem_def_sp,
-                             PolChemDefWnd *pol_chem_def_wnd_p,
-                             const QString &settings_file_path,
-                             const QString &application_name,
-                             const QString &description)
-  : AbstractPolChemDefDependentDlg(pol_chem_def_sp,
-                                   pol_chem_def_wnd_p,
-                                   settings_file_path,
+
+MonomerDefDlg::MonomerDefDlg(PolChemDef *polChemDef,
+                             PolChemDefWnd *polChemDefWnd,
+                             const QString &settingsFilePath)
+  : AbstractPolChemDefDependentDlg{polChemDef,
+                                   polChemDefWnd,
+                                   settingsFilePath,
                                    "MonomerDefDlg",
-                                   application_name,
-                                   description),
-    mref_monomers(pol_chem_def_sp->getMonomersRef())
+                                   "massXpert: Monomer definition"}
 {
+  mp_list = polChemDef->monomerListPtr();
+
   if(!initialize())
-    qFatal() << "Failed to initialize the dialog window.";
+    qFatal(
+      "Fatal error at %s@%d. Failed to initialize the %s window. Program "
+      "aborted.",
+      __FILE__,
+      __LINE__,
+      m_wndTypeName.toLatin1().data());
 }
 
 
@@ -83,7 +82,7 @@ MonomerDefDlg::closeEvent([[maybe_unused]] QCloseEvent *event)
   // close==destruction. Thus we only hide the dialog remembering its
   // position and size.
 
-  mp_pol_chem_def_wnd_p->m_ui.monomerPushButton->setChecked(false);
+  mp_polChemDefWnd->m_ui.monomerPushButton->setChecked(false);
 
   writeSettings();
 }
@@ -92,7 +91,7 @@ MonomerDefDlg::closeEvent([[maybe_unused]] QCloseEvent *event)
 void
 MonomerDefDlg::readSettings()
 {
-  QSettings settings(m_settings_file_path, QSettings::IniFormat);
+  QSettings settings(m_settingsFilePath, QSettings::IniFormat);
 
   settings.beginGroup(m_wndTypeName);
   restoreGeometry(settings.value("geometry").toByteArray());
@@ -105,7 +104,7 @@ void
 MonomerDefDlg::writeSettings()
 {
 
-  QSettings settings(m_settings_file_path, QSettings::IniFormat);
+  QSettings settings(m_settingsFilePath, QSettings::IniFormat);
 
   settings.beginGroup(m_wndTypeName);
   restoreGeometry(settings.value("geometry").toByteArray());
@@ -119,27 +118,26 @@ MonomerDefDlg::initialize()
 {
   m_ui.setupUi(this);
 
-  setWindowIcon(qApp->windowIcon());
-
-  // Now we need to actually show the window title (that element is empty in
-  // m_ui)
-  displayWindowTitle();
-
   // Set all the monomers to the list widget.
-  for(libXpertMassCore::MonomerSPtr monomer_sp : mref_monomers)
-    m_ui.monomerListWidget->addItem(monomer_sp->getName());
+
+  for(int iter = 0; iter < mp_list->size(); ++iter)
+    {
+      Monomer *monomer = mp_list->at(iter);
+
+      m_ui.monomerListWidget->addItem(monomer->name());
+    }
 
   readSettings();
 
   // Get the monomer code length and create a validator for use later.
 
-  m_ui.codeLengthSpinBox->setValue(msp_polChemDef->getCodeLength());
+  m_ui.codeLengthSpinBox->setValue(mp_polChemDef->codeLength());
 
   QString regExp =
-    QString("[A-Z][a-z]{0,%1}").arg(msp_polChemDef->getCodeLength() - 1);
+    QString("[A-Z][a-z]{0,%1}").arg(mp_polChemDef->codeLength() - 1);
 
-  QRegularExpression codeRegExp(regExp);
-  QValidator *validator = new QRegularExpressionValidator(codeRegExp, this);
+  QRegExp codeRegExp(regExp);
+  QValidator *validator = new QRegExpValidator(codeRegExp, this);
 
   m_ui.codeLineEdit->setValidator(validator);
 
@@ -209,12 +207,11 @@ MonomerDefDlg::addMonomerPushButtonClicked()
   // Returns -1 if the list is empty.
   int index = m_ui.monomerListWidget->currentRow();
 
-  libXpertMassCore::MonomerSPtr monomer_sp =
-    std::make_shared<libXpertMassCore::Monomer>(
-      msp_polChemDef, tr("Type Name"), tr("Type Code"), tr("Type Formula"));
+  Monomer *newMonomer = new Monomer(
+    mp_polChemDef, tr("Type Name"), tr("Type Code"), tr("Type Formula"));
 
-  mref_monomers.insert(mref_monomers.begin() + index, monomer_sp);
-  m_ui.monomerListWidget->insertItem(index, monomer_sp->getName());
+  mp_list->insert(index, newMonomer);
+  m_ui.monomerListWidget->insertItem(index, newMonomer->name());
 
   setModified();
 
@@ -246,7 +243,9 @@ MonomerDefDlg::removeMonomerPushButtonClicked()
   QListWidgetItem *item = m_ui.monomerListWidget->takeItem(index);
   delete item;
 
-  mref_monomers.erase(mref_monomers.begin() + index);
+  Monomer *monomer = mp_list->takeAt(index);
+  Q_ASSERT(monomer);
+  delete monomer;
 
   setModified();
 
@@ -286,11 +285,11 @@ MonomerDefDlg::moveUpMonomerPushButtonClicked()
   // Get the index of the monomer and the monomer itself.
   int index = m_ui.monomerListWidget->currentRow();
 
-  auto it = mref_monomers.begin() + index;
   // If the item is already at top of list, do nothing.
-  if(it == mref_monomers.begin())
+  if(!index)
     return;
-  std::iter_swap(it, it - 1); // Swap with the previous element
+
+  mp_list->move(index, index - 1);
 
   QListWidgetItem *item = m_ui.monomerListWidget->takeItem(index);
 
@@ -318,11 +317,11 @@ MonomerDefDlg::moveDownMonomerPushButtonClicked()
   // Get the index of the monomer and the monomer itself.
   int index = m_ui.monomerListWidget->currentRow();
 
-  auto it = mref_monomers.begin() + index;
   // If the item is already at bottom of list, do nothing.
-  if(it == mref_monomers.end())
+  if(index == m_ui.monomerListWidget->count() - 1)
     return;
-  std::iter_swap(it, it + 1); // Swap with the next element
+
+  mp_list->move(index, index + 1);
 
   QListWidgetItem *item = m_ui.monomerListWidget->takeItem(index);
   m_ui.monomerListWidget->insertItem(index + 1, item);
@@ -349,7 +348,7 @@ MonomerDefDlg::applyMonomerPushButtonClicked()
   // Get the index of the current monomer item.
   int index = m_ui.monomerListWidget->currentRow();
 
-  libXpertMassCore::MonomerSPtr monomer_sp = mref_monomers.at(index);
+  Monomer *monomer = mp_list->at(index);
 
   // We do not want more than one monomer by the same name or the same
   // symbol.
@@ -362,58 +361,38 @@ MonomerDefDlg::applyMonomerPushButtonClicked()
 
   QString editFormula = m_ui.formulaLineEdit->text();
 
-  // If a monomer is found in the member ref to vector with any of these two
-  // strings, and that monomer is not the one that is current in that vector,
+  // If a monomer is found in the list with any of these two strings,
+  // and that monomer is not the one that is current in the monomer list,
   // then we are making a double entry, which is not allowed.
 
-  std::vector<libXpertMassCore::MonomerSPtr>::iterator the_iterator =
-    std::find_if(mref_monomers.begin(),
-                 mref_monomers.end(),
-                 [editName](const libXpertMassCore::MonomerSPtr iter_monomer_sp) {
-                   return iter_monomer_sp->getName() == editName;
-                 });
-
-  if(the_iterator != mref_monomers.end() &&
-     std::distance(mref_monomers.begin(), the_iterator) != index)
+  int nameRes = Monomer::isNameInList(editName, *mp_list);
+  if(nameRes != -1 && nameRes != index)
     {
       QMessageBox::warning(this,
-                           tr("MassXpert3 - Monomer definition"),
-                           tr("A monomer with same name "
-                              "exists already."),
+                           tr("massXpert - Monomer definition"),
+                           tr("A monomer with same name exists already."),
                            QMessageBox::Ok);
       return;
     }
 
-  the_iterator =
-    std::find_if(mref_monomers.begin(),
-                 mref_monomers.end(),
-                 [editCode](const libXpertMassCore::MonomerSPtr iter_monomer_sp) {
-                   return iter_monomer_sp->getCode() == editCode;
-                 });
-
-  if(the_iterator != mref_monomers.end() &&
-     std::distance(mref_monomers.begin(), the_iterator) != index)
+  int codeRes = Monomer::isCodeInList(editCode, *mp_list);
+  if(codeRes != -1 && codeRes != index)
     {
       QMessageBox::warning(this,
-                           tr("MassXpert3 - Monomer definition"),
-                           tr("A monomer with same code "
-                              "exists already."),
+                           tr("massXpert - Monomer definition"),
+                           tr("A monomer with same code exists already."),
                            QMessageBox::Ok);
       return;
     }
 
   // At this point, validate the formula:
 
-  libXpertMassCore::Formula formula(editFormula);
+  Formula formula(editFormula);
 
-  libXpertMassCore::IsotopicDataCstSPtr isotopic_data_csp =
-    msp_polChemDef->getIsotopicDataCstSPtr();
-  libXpertMassCore::ErrorList error_list;
-
-  if(!formula.validate(isotopic_data_csp, &error_list))
+  if(!formula.validate(mp_polChemDef->atomList()))
     {
       QMessageBox::warning(this,
-                           tr("MassXpert3 - Monomer definition"),
+                           tr("massXpert - Monomer definition"),
                            tr("The formula failed to validate."),
                            QMessageBox::Ok);
       return;
@@ -421,14 +400,14 @@ MonomerDefDlg::applyMonomerPushButtonClicked()
 
   // Finally we can update the monomer's data:
 
-  monomer_sp->setName(editName);
-  monomer_sp->setCode(editCode);
-  monomer_sp->setFormula(editFormula);
+  monomer->setName(editName);
+  monomer->setCode(editCode);
+  monomer->setFormula(editFormula);
 
   // Update the list widget item.
 
   QListWidgetItem *item = m_ui.monomerListWidget->currentItem();
-  item->setData(Qt::DisplayRole, monomer_sp->getName());
+  item->setData(Qt::DisplayRole, monomer->name());
 
   setModified();
 }
@@ -444,9 +423,9 @@ MonomerDefDlg::validatePushButtonClicked()
   // everything is fine and that colinearity is perfect between the
   // monomer list and the listwidget.
 
-  std::size_t item_count = m_ui.monomerListWidget->count();
+  int itemCount = m_ui.monomerListWidget->count();
 
-  if(item_count != mref_monomers.size())
+  if(itemCount != mp_list->size())
     {
       errorList << QString(
         tr("\nThe number of monomers in the "
@@ -455,38 +434,33 @@ MonomerDefDlg::validatePushButtonClicked()
            "not identical.\n"));
 
       QMessageBox::warning(this,
-                           tr("MassXpert3 - Monomer definition"),
+                           tr("massXpert - Monomer definition"),
                            errorList.join("\n"),
                            QMessageBox::Ok);
       return false;
     }
 
-  for(std::size_t iter = 0; iter < mref_monomers.size(); ++iter)
+  for(int iter = 0; iter < mp_list->size(); ++iter)
     {
       QListWidgetItem *item = m_ui.monomerListWidget->item(iter);
 
-      libXpertMassCore::MonomerSPtr monomer_sp = mref_monomers.at(iter);
+      Monomer *monomer = mp_list->at(iter);
 
-      if(item->text() != monomer_sp->getName())
+      if(item->text() != monomer->name())
         errorList << QString(tr("\nMonomer at index %1 has not the same\n"
                                 "name as the list widget item at the\n"
                                 "same index.\n")
                                .arg(iter));
 
-      MsXpS::libXpertMassCore::ErrorList error_list;
-
-      if(!monomer_sp->validate(&error_list))
+      if(!monomer->validate())
         errorList << QString(
-                       "\nMonomer at index %1  failed to validate.\n"
-                       "Errors: %2\n\n")
-                       .arg(iter)
-                       .arg(libXpertMassCore::Utils::joinErrorList(error_list));
+          tr("\nMonomer at index %1  failed to validate.\n").arg(iter));
     }
 
   if(errorList.size())
     {
       QMessageBox::warning(this,
-                           tr("MassXpert3 - Monomer definition"),
+                           tr("massXpert - Monomer definition"),
                            errorList.join("\n"),
                            QMessageBox::Ok);
       return false;
@@ -494,7 +468,7 @@ MonomerDefDlg::validatePushButtonClicked()
   else
     {
       QMessageBox::warning(this,
-                           tr("MassXpert3 - Monomer definition"),
+                           tr("massXpert - Monomer definition"),
                            ("Validation: success\n"),
                            QMessageBox::Ok);
     }
@@ -519,18 +493,15 @@ MonomerDefDlg::monomerListWidgetItemSelectionChanged()
   // Get the index of the current monomer.
   int index = m_ui.monomerListWidget->currentRow();
 
-  // Note that this should not occur, I guess, but once I got this crash, so
+  // Note that this should not occur, I gess, but one I got this crash, so
   // test that the returned index is not -1.
   if(index >= 0)
     {
-      libXpertMassCore::MonomerSPtr monomer_sp = mref_monomers.at(index);
-      if(monomer_sp == nullptr)
-        qFatal() << "Programming error.";
-
-      // qDebug() << "Currently selected monomer:" << monomer->name();
+      Monomer *monomer = mp_list->at(index);
+      Q_ASSERT(monomer);
 
       // Set the data of the monomer to their respective widgets.
-      updateMonomerDetails(monomer_sp);
+      updateMonomerDetails(monomer);
     }
 }
 
@@ -549,26 +520,26 @@ MonomerDefDlg::codeLengthSpinBoxValueChanged(int value)
   QString regExp = QString("[A-Z][a-z]{0,%1}").arg(value - 1);
   //    qDebug() << "new regExp:" << regExp;
 
-  QRegularExpression codeRegExp(regExp);
-  QValidator *validator = new QRegularExpressionValidator(codeRegExp, this);
+  QRegExp codeRegExp(regExp);
+  QValidator *validator = new QRegExpValidator(codeRegExp, this);
 
   m_ui.codeLineEdit->setValidator(validator);
 
   // And now inform the whole polymer definition that the codeLength
   // value has changed.
 
-  msp_polChemDef->setCodeLength(value);
+  mp_polChemDef->setCodeLength(value);
 }
 
 
 void
-MonomerDefDlg::updateMonomerDetails(libXpertMassCore::MonomerSPtr monomer_sp)
+MonomerDefDlg::updateMonomerDetails(Monomer *monomer)
 {
-  if(monomer_sp != nullptr)
+  if(monomer)
     {
-      m_ui.nameLineEdit->setText(monomer_sp->getName());
-      m_ui.codeLineEdit->setText(monomer_sp->getCode());
-      m_ui.formulaLineEdit->setText(monomer_sp->getFormula());
+      m_ui.nameLineEdit->setText(monomer->name());
+      m_ui.codeLineEdit->setText(monomer->code());
+      m_ui.formulaLineEdit->setText(monomer->formula());
     }
   else
     {
@@ -602,21 +573,13 @@ MonomerDefDlg::formulaLineEditTextChanged(const QString &string)
   // masses of the formula. If the computation failed, we set "Bad
   // formula" in the line edit widgets of the masses.
 
-  libXpertMassCore::IsotopicDataCstSPtr isotopic_data_csp =
-    msp_polChemDef->getIsotopicDataCstSPtr();
+  const QList<Atom *> &atomList = mp_polChemDef->atomList();
 
+  Formula formula(string);
 
-  libXpertMassCore::Formula formula(string);
+  Ponderable ponderable(0, 0);
 
-  // qDebug() << "Formula of the monomer:" << string;
-
-  double mono = 0;
-  double avg  = 0;
-  bool ok     = false;
-
-  formula.accountMasses(ok, isotopic_data_csp, mono, avg);
-
-  if(!ok)
+  if(!formula.accountMasses(atomList, &ponderable))
     {
       m_ui.monoMassLineEdit->setText(tr("Bad formula"));
       m_ui.avgMassLineEdit->setText(tr("Bad formula"));
@@ -624,10 +587,9 @@ MonomerDefDlg::formulaLineEditTextChanged(const QString &string)
       return;
     }
 
-  m_ui.monoMassLineEdit->setText(
-    QString::number(mono, 'f', libXpertMassCore::ATOM_DEC_PLACES));
-  m_ui.avgMassLineEdit->setText(
-    QString::number(avg, 'f', libXpertMassCore::ATOM_DEC_PLACES));
+  m_ui.monoMassLineEdit->setText(ponderable.monoString(ATOM_DEC_PLACES));
+
+  m_ui.avgMassLineEdit->setText(ponderable.avgString(ATOM_DEC_PLACES));
 }
 
 
@@ -645,7 +607,7 @@ MonomerDefDlg::calculateMassDifferences()
   if(!threshold && !ok)
     {
       QMessageBox::warning(this,
-                           tr("MassXpert3 - Monomer definition"),
+                           tr("massXpert - Monomer definition"),
                            tr("Threshold value is not valid"),
                            QMessageBox::Ok);
       return;
@@ -653,28 +615,30 @@ MonomerDefDlg::calculateMassDifferences()
 
   bool isMonoMass = m_ui.monoMassRadioButton->isChecked();
 
-  libXpertMassCore::Enums::MassType monoOrAvg;
+  int monoOrAvg;
 
   if(isMonoMass)
-    monoOrAvg = libXpertMassCore::Enums::MassType::MONO;
+    monoOrAvg = MassType::MASS_MONO;
   else
-    monoOrAvg = libXpertMassCore::Enums::MassType::AVG;
+    monoOrAvg = MassType::MASS_AVG;
 
-  QStringList diffList =
-    msp_polChemDef->differenceBetweenMonomers(threshold, monoOrAvg);
+  QStringList *diffList =
+    mp_polChemDef->differenceBetweenMonomers(threshold, monoOrAvg);
 
-  if(!diffList.size())
+  if(!diffList)
     return;
 
   QMessageBox::information(this,
-                           tr("MassXpert3 - Monomer definition"),
-                           diffList.join("\n"),
+                           tr("massXpert - Monomer definition"),
+                           diffList->join("\n"),
                            QMessageBox::Ok);
 
+  delete diffList;
+
   return;
 }
 
 
-} // namespace MassXpert
+} // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
