@@ -41,10 +41,10 @@
 
 /////////////////////// Local includes
 #include "MzLabWnd.hpp"
-#include <libXpertMass/globals.hpp>
+#include "../nongui/globals.hpp"
 #include "ui_MzLabFormulaBasedActionsDlg.h"
 
-namespace MsXpS
+namespace msxps
 {
 
 	namespace massxpert
@@ -78,7 +78,7 @@ class MzLabFormulaBasedActionsDlg : public QDialog
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
 
 #endif // MZ_LAB_FORMULA_BASED_ACTIONS_DLG_HPP
