@@ -40,12 +40,12 @@
 
 
 /////////////////////// Local includes
-#include <libXpertMass/Oligomer.hpp>
+#include "../nongui/Oligomer.hpp"
 #include "MzLabInputOligomerTableViewDlg.hpp"
 #include "MzLabWnd.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
 	namespace massxpert
@@ -77,7 +77,7 @@ class MzLabInputOligomerTableViewModel : public QAbstractTableModel
 
   // Fixme: does not this belong to the dialog? Maybe a pointer to
   // the other one should be better.
-  libXpertMass::MassType m_massType;
+  MassType m_massType;
 
   public:
   MzLabInputOligomerTableViewModel(OligomerList *, QObject *);
@@ -104,13 +104,13 @@ class MzLabInputOligomerTableViewModel : public QAbstractTableModel
   QVariant data(const QModelIndex &parent = QModelIndex(),
                 int role                  = Qt::DisplayRole) const;
 
-  int addOligomer(libXpertMass::OligomerSPtr oligomer_sp);
+  int addOligomer(Oligomer *);
   int removeOligomers(int, int);
 };
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
 
 #endif // MZ_LAB_INPUT_OLIGOMER_TABLE_VIEW_MODEL_HPP
