@@ -40,11 +40,11 @@
 
 
 /////////////////////// Local includes
-#include <libXpertMass/globals.hpp>
+#include "../nongui/globals.hpp"
 #include "MzLabInputOligomerTableViewDlg.hpp"
 #include "ui_MzLabMatchBasedActionsDlg.h"
 
-namespace MsXpS
+namespace msxps
 {
 
 	namespace massxpert
@@ -74,7 +74,7 @@ class MzLabMatchBasedActionsDlg : public QDialog
 
   void fillMolecularMassList(const OligomerList &,
                              QList<double> *,
-                             libXpertMass::MassType &);
+                             MassType &);
 
   private slots:
   void performMatchWorkPushButton();
@@ -83,7 +83,7 @@ class MzLabMatchBasedActionsDlg : public QDialog
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
 
 #endif // MZ_LAB_MATCH_BASED_ACTIONS_DLG_HPP
