@@ -40,13 +40,13 @@
 
 
 /////////////////////// Local includes
-#include <libXpertMass/Oligomer.hpp>
+#include "../nongui/Oligomer.hpp"
 #include "../nongui/OligomerList.hpp"
 #include "MzLabOutputOligomerTableView.hpp"
 #include "MzLabWnd.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
 	namespace massxpert
@@ -75,7 +75,7 @@ class MzLabOutputOligomerTableViewModel : public QAbstractTableModel
   Q_OBJECT
 
   private:
-  QList<OligomerPairSPtr> *mp_oligomerPairList;
+  QList<OligomerPair *> *mp_oligomerPairList;
 
   MzLabOutputOligomerTableView *mp_tableView;
 
@@ -84,10 +84,10 @@ class MzLabOutputOligomerTableViewModel : public QAbstractTableModel
 
   // Fixme: does not this belong to the dialog? Maybe a pointer to
   // the other one should be better.
-  libXpertMass::MassType m_massType;
+  MassType m_massType;
 
   public:
-  MzLabOutputOligomerTableViewModel(QList<OligomerPairSPtr> *, QObject *);
+  MzLabOutputOligomerTableViewModel(QList<OligomerPair *> *, QObject *);
   ~MzLabOutputOligomerTableViewModel();
 
   void setParentDlg(MzLabOutputOligomerTableViewDlg *);
@@ -109,12 +109,12 @@ class MzLabOutputOligomerTableViewModel : public QAbstractTableModel
   QVariant data(const QModelIndex &parent = QModelIndex(),
                 int role                  = Qt::DisplayRole) const;
 
-  void addOligomerPair(OligomerPairSPtr);
+  void addOligomerPair(OligomerPair *);
 };
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
 
 #endif // MZ_LAB_OUTPUT_OLIGOMER_TABLE_VIEW_MODEL_HPP
