@@ -36,31 +36,42 @@
 
 
 /////////////////////// Local includes
-#include <libXpertMass/CleaveSpec.hpp>
-#include <libXpertMass/globals.hpp>
-#include <libXpertMass/PolChemDefEntity.hpp>
+#include "CleaveSpec.hpp"
+#include "globals.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace massxpert
-{
+	namespace massxpert
+	{
 
 
-class CleaveOptions : public libXpertMass::CleaveSpec
+
+class CleaveOptions : public CleaveSpec
 {
+  private:
+  int m_partials;
+
+  // These two values have to be both positive and in increasing order
+  // or equal. That is m_endIonizeLevel >= m_startIonizeLevel. Only
+  // use access functions to set their values.
+  int m_startIonizeLevel;
+  int m_endIonizeLevel;
+
+  bool m_sequenceEmbedded;
+
   public:
-  CleaveOptions(
-    libXpertMass::PolChemDefCstSPtr, QString, QString, int = 0, bool = false);
+  CleaveOptions(PolChemDef *, QString, QString, int = 0, bool = false);
 
-  CleaveOptions(const libXpertMass::CleaveSpec &, int = 0, bool = false);
+  CleaveOptions(const CleaveSpec &, int = 0, bool = false);
 
-  CleaveOptions(const CleaveOptions &other);
+  CleaveOptions(const CleaveOptions &);
 
   ~CleaveOptions();
 
-  CleaveOptions &operator=(const CleaveOptions &other);
+  void clone(CleaveOptions *) const;
+  void mold(const CleaveOptions &);
 
   void setPartials(int);
   int partials() const;
@@ -76,22 +87,11 @@ class CleaveOptions : public libXpertMass::CleaveSpec
 
   void setSequenceEmbedded(bool);
   bool isSequenceEmbedded() const;
-
-  private:
-  int m_partials;
-
-  // These two values have to be both positive and in increasing order
-  // or equal. That is m_endIonizeLevel >= m_startIonizeLevel. Only
-  // use access functions to set their values.
-  int m_startIonizeLevel;
-  int m_endIonizeLevel;
-
-  bool m_sequenceEmbedded;
 };
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
 
 #endif // CLEAVE_OPTIONS_HPP
