@@ -36,35 +36,50 @@
 
 
 /////////////////////// Local includes
-#include <libXpertMass/FragSpec.hpp>
-#include <libXpertMass/globals.hpp>
-#include <libXpertMass/PolChemDefEntity.hpp>
+#include "FragSpec.hpp"
+#include "globals.hpp"
 
 
-namespace MsXpS {
+namespace msxps {
 
 
 	namespace massxpert
 	{
 
 
-class FragOptions : public libXpertMass::FragSpec
+class FragOptions : public FragSpec
 {
+  private:
+  int m_startIndex;
+  int m_endIndex;
+
+  // These two values have to be both positive and in increasing order
+  // or equal. That is m_endIonizeLevel >= m_startIonizeLevel. Only
+  // use access functions to set their values.
+  int m_startIonizeLevel;
+  int m_endIonizeLevel;
+
+  bool m_sequenceEmbedded;
+
+  QList<Formula *> m_formulaList;
+
   public:
-  FragOptions(libXpertMass::PolChemDefCstSPtr,
+  FragOptions(PolChemDef *,
               QString,
               QString,
-              libXpertMass::FragEnd      = libXpertMass::FragEnd::FRAG_END_NONE,
+              MxtFragEnd      = FRAG_END_NONE,
               const QString & = QString(),
               bool            = false);
 
-  FragOptions(const libXpertMass::FragSpec &, int = 0, int = 0, bool = false);
+  FragOptions(const FragSpec &, int = 0, int = 0, bool = false);
 
-  FragOptions(const FragOptions &other);
+  FragOptions(const FragOptions &);
 
   ~FragOptions();
 
-  FragOptions &operator=(const FragOptions &other);
+  FragOptions *clone() const;
+  void clone(FragOptions *) const;
+  void mold(const FragOptions &);
 
   void setStartIonizeLevel(int);
   int startIonizeLevel() const;
@@ -78,33 +93,17 @@ class FragOptions : public libXpertMass::FragSpec
   void setEndIndex(int);
   int endIndex() const;
 
-  bool addFormula(const libXpertMass::Formula &);
+  bool addFormula(const Formula &);
   bool addFormula(const QString &);
-  const QList<libXpertMass::Formula *> &formulaList();
+  const QList<Formula *> &formulaList();
 
   void setSequenceEmbedded(bool);
   bool isSequenceEmbedded() const;
-
-  QString toString() const;
-
-  private:
-  int m_startIndex;
-  int m_endIndex;
-
-  // These two values have to be both positive and in increasing order
-  // or equal. That is m_endIonizeLevel >= m_startIonizeLevel. Only
-  // use access functions to set their values.
-  int m_startIonizeLevel;
-  int m_endIonizeLevel;
-
-  bool m_sequenceEmbedded;
-
-  QList<libXpertMass::Formula *> m_formulaList;
 };
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
 
 #endif // FRAG_OPTIONS_HPP
