@@ -41,7 +41,7 @@
 #include <QDebug>
 
 
-namespace MsXpS {
+namespace msxps {
 
 
 	namespace massxpert
@@ -67,6 +67,9 @@ class MassList
 
   ~MassList();
 
+  MassList *clone() const;
+  void clone(MassList *) const;
+  void mold(const MassList &);
   MassList &operator=(const MassList &);
 
   void setName(QString);
@@ -95,7 +98,7 @@ class MassList
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
 
 
 #endif // MASS_LIST_HPP
