@@ -32,47 +32,48 @@
 
 
 /////////////////////// Local includes
-#include <libXpertMass/globals.hpp>
+#include "../nongui/globals.hpp"
 #include "OligomerPair.hpp"
-#include <libXpertMass/Oligomer.hpp>
+#include "Oligomer.hpp"
 
 
-namespace MsXpS
+namespace msxps
 {
 
-namespace massxpert
-{
+	namespace massxpert
+	{
 
 
-OligomerPair::OligomerPair(const libXpertMass::OligomerSPtr oligomer1_sp,
-                           const libXpertMass::OligomerSPtr oligomer2_sp,
-                           libXpertMass::MassType massType,
+
+
+OligomerPair::OligomerPair(const Oligomer *oligomer1,
+                           const Oligomer *oligomer2,
+                           MassType massType,
                            double error,
                            bool isMatching,
                            const QString &name)
-  : msp_oligomer1(oligomer1_sp),
-    msp_oligomer2(oligomer2_sp),
+  : mp_oligomer1(oligomer1),
+    mp_oligomer2(oligomer2),
     m_massType(massType),
     m_error(error),
     m_isMatching(isMatching),
     m_name(name)
 {
-  Q_ASSERT(msp_oligomer1);
-  Q_ASSERT(msp_oligomer2);
+  Q_ASSERT(mp_oligomer1);
+  Q_ASSERT(mp_oligomer2);
 }
 
 
 OligomerPair::OligomerPair(const OligomerPair &other)
-  : libXpertMass::PropListHolder(other),
-    msp_oligomer1(other.msp_oligomer1),
-    msp_oligomer2(other.msp_oligomer2),
+  : PropListHolder(other), mp_oligomer1(other.mp_oligomer1),
+    mp_oligomer2(other.mp_oligomer2),
     m_massType(other.m_massType),
     m_error(other.m_error),
     m_isMatching(other.m_isMatching),
     m_name(other.m_name)
 {
-  Q_ASSERT(msp_oligomer1);
-  Q_ASSERT(msp_oligomer2);
+  Q_ASSERT(mp_oligomer1);
+  Q_ASSERT(mp_oligomer2);
 }
 
 
@@ -88,17 +89,17 @@ OligomerPair::name()
 }
 
 
-const libXpertMass::OligomerSPtr
+const Oligomer *
 OligomerPair::oligomer1() const
 {
-  return msp_oligomer1;
+  return mp_oligomer1;
 }
 
 
-const libXpertMass::OligomerSPtr
+const Oligomer *
 OligomerPair::oligomer2() const
 {
-  return msp_oligomer2;
+  return mp_oligomer2;
 }
 
 
@@ -109,7 +110,7 @@ OligomerPair::setError(double error)
 }
 
 
-libXpertMass::MassType
+MassType
 OligomerPair::massType() const
 {
   return m_massType;
@@ -117,7 +118,7 @@ OligomerPair::massType() const
 
 
 void
-OligomerPair::setMassType(libXpertMass::MassType massType)
+OligomerPair::setMassType(MassType massType)
 {
   m_massType = massType;
 }
@@ -147,30 +148,30 @@ OligomerPair::isMatching() const
 double
 OligomerPair::mass1()
 {
-  return msp_oligomer1->mass(m_massType);
+  return mp_oligomer1->mass(m_massType);
 }
 
 
 int
 OligomerPair::charge1()
 {
-  return msp_oligomer1->charge();
+  return mp_oligomer1->charge();
 }
 
 
 double
 OligomerPair::mass2()
 {
-  return msp_oligomer2->mass(m_massType);
+  return mp_oligomer2->mass(m_massType);
 }
 
 
 int
 OligomerPair::charge2()
 {
-  return msp_oligomer2->charge();
+  return mp_oligomer2->charge();
 }
 
 } // namespace massxpert
 
-} // namespace MsXpS
+} // namespace msxps
