@@ -42,14 +42,15 @@
 namespace msxps
 {
 
-namespace massxpert
-{
+	namespace massxpert
+	{
 
 
-PkaPhPi::PkaPhPi(libmass::Polymer &polymer,
-                 libmass::CalcOptions &calcOptions,
-                 QList<libmass::Monomer *> *monomerList,
-                 QList<libmass::Modif *> *modifList)
+
+PkaPhPi::PkaPhPi(Polymer &polymer,
+                 CalcOptions &calcOptions,
+                 QList<Monomer *> *monomerList,
+                 QList<Modif *> *modifList)
   : m_polymer(polymer),
     m_calcOptions(calcOptions),
     mpa_monomerList(monomerList),
@@ -126,14 +127,14 @@ PkaPhPi::negativeCharges()
 
 
 void
-PkaPhPi::setCalcOptions(const libmass::CalcOptions &calcOptions)
+PkaPhPi::setCalcOptions(const CalcOptions &calcOptions)
 {
   m_calcOptions = calcOptions;
 }
 
 
 void
-PkaPhPi::setMonomerList(QList<libmass::Monomer *> *monomerList)
+PkaPhPi::setMonomerList(QList<Monomer *> *monomerList)
 {
   Q_ASSERT(monomerList);
 
@@ -142,7 +143,7 @@ PkaPhPi::setMonomerList(QList<libmass::Monomer *> *monomerList)
 
 
 void
-PkaPhPi::setModifList(QList<libmass::Modif *> *modifList)
+PkaPhPi::setModifList(QList<Modif *> *modifList)
 {
   Q_ASSERT(modifList);
 
@@ -169,17 +170,16 @@ PkaPhPi::calculateCharges()
   // Get the list of the coordinates of the different region
   // selections. For each first monomer and end monomer of a given
   // region selection, check if the the region is an oligomer or a
-  // residual chain(m_selectionType of libmass::CalcOptions); act
+  // residual chain(m_selectionType of CalcOptions); act
   // accordingly. Also, check for each selection region if it
   // encompasses the polymer left/right end. If the left/right end
   // modifications are to be taken into account, act accordingly.
 
-  const libmass::CoordinateList &coordinateList =
-    m_calcOptions.coordinateList();
+  const CoordinateList &coordinateList = m_calcOptions.coordinateList();
 
   for(int iter = 0; iter < coordinateList.size(); ++iter)
     {
-      libmass::Coordinates *coordinates = coordinateList.at(iter);
+      Coordinates *coordinates = coordinateList.at(iter);
 
       int startIndex = coordinates->start();
       int endIndex   = coordinates->end();
@@ -191,10 +191,10 @@ PkaPhPi::calculateCharges()
 
       for(int jter = startIndex; jter < endIndex + 1; ++jter)
         {
-          const libmass::Monomer *seqMonomer = m_polymer.at(jter);
+          const Monomer *seqMonomer = m_polymer.at(jter);
 
           // 	    qDebug() << __FILE__ << __LINE__
-          // 		      << "-- libmass::Monomer:" << seqMonomer->name()
+          // 		      << "-- Monomer:" << seqMonomer->name()
           // 		      << "position:" << jter + 1;
 
           // Find a monomer by the same code in our list of monomers
@@ -204,24 +204,24 @@ PkaPhPi::calculateCharges()
           // monoemers. For example, there might be cases in which a
           // given monomer might not bring any charge whatsoever.
 
-          int index = libmass::Monomer::isCodeInList(seqMonomer->code(),
-                                                     *mpa_monomerList);
+          int index =
+            Monomer::isCodeInList(seqMonomer->code(), *mpa_monomerList);
           if(index == -1)
             return -1;
 
-          const libmass::Monomer *monomer = mpa_monomerList->at(index);
+          const Monomer *monomer = mpa_monomerList->at(index);
           Q_ASSERT(monomer);
 
           // A monomer can have multiple such "CHEMICAL_GROUP"
           // properties. Indeed, for example for proteins, a monomer
           // might have three such chemical groups(and thus three
-          // libmass::Prop objects): one for the alpha NH2, one for the alpha
+          // Prop objects): one for the alpha NH2, one for the alpha
           // COOH and one for a residual chain chemical group, like
           // epsilon NH2 for lysine.
 
           for(int kter = 0; kter < monomer->propList().size(); ++kter)
             {
-              libmass::Prop *prop = monomer->propList().at(kter);
+              Prop *prop = monomer->propList().at(kter);
 
               if(prop->name() != "CHEMICAL_GROUP")
                 continue;
@@ -231,10 +231,10 @@ PkaPhPi::calculateCharges()
 
               // Get the chemical group out of the property.
 
-              libmass::ChemicalGroup *chemicalGroup =
-                static_cast<libmass::ChemicalGroup *>(prop->data());
+              ChemicalGroup *chemicalGroup =
+                static_cast<ChemicalGroup *>(prop->data());
 
-              if(chemicalGroup->polRule() & libmass::CHEMGROUP_LEFT_TRAPPED)
+              if(chemicalGroup->polRule() & CHEMGROUP_LEFT_TRAPPED)
                 {
                   // 		    qDebug() << __FILE__ << __LINE__
                   // 			      << "... that is CHEMGROUP_LEFT_TRAPPED";
@@ -263,30 +263,30 @@ PkaPhPi::calculateCharges()
 
                       if(!leftMostCoordinates)
                         {
-                          // The current libmass::Coordinates is not the
-                          // left-most libmass::Coordinates in the
-                          // libmass::CoordinateList, thus we cannot consider
+                          // The current Coordinates is not the
+                          // left-most Coordinates in the
+                          // CoordinateList, thus we cannot consider
                           // it to be the "left end coordinates" of
-                          // the libmass::CoordinateList. Just continue
+                          // the CoordinateList. Just continue
                           // without exploring any more.
                           continue;
                         }
                       if(jter == startIndex)
                         {
                           // The current monomer is the first
-                          // monomer of libmass::Coordinates. We only take
+                          // monomer of Coordinates. We only take
                           // into account the chemical group if each
-                          // libmass::Coordinates is to be considered an
+                          // Coordinates is to be considered an
                           // oligomer.
 
                           if(m_calcOptions.selectionType() !=
-                             libmass::SELECTION_TYPE_OLIGOMERS)
+                             SELECTION_TYPE_OLIGOMERS)
                             continue;
                         }
                     }
                 }
 
-              if(chemicalGroup->polRule() & libmass::CHEMGROUP_RIGHT_TRAPPED)
+              if(chemicalGroup->polRule() & CHEMGROUP_RIGHT_TRAPPED)
                 {
                   // 		    qDebug() << __FILE__ << __LINE__
                   // 			      << "... that is CHEMGROUP_RIGHT_TRAPPED";
@@ -300,31 +300,31 @@ PkaPhPi::calculateCharges()
 
                       if(!rightMostCoordinates)
                         {
-                          // The current libmass::Coordinates is not the
-                          // right-most libmass::Coordinates of the
-                          // libmass::CoordinateList, thus we cannot consider
+                          // The current Coordinates is not the
+                          // right-most Coordinates of the
+                          // CoordinateList, thus we cannot consider
                           // it to be the "right end coordinates" of
-                          // the libmass::CoordinateList. Just continue
+                          // the CoordinateList. Just continue
                           // without exploring anymore.
                           continue;
                         }
                       if(jter == endIndex)
                         {
                           // The current monomer is the last monomer
-                          // of libmass::Coordinates. We only take into
+                          // of Coordinates. We only take into
                           // account the chemical group if each
-                          // libmass::Coordinates is to be considered an
+                          // Coordinates is to be considered an
                           // oligomer(and not a residual chain).
 
                           if(m_calcOptions.selectionType() !=
-                             libmass::SELECTION_TYPE_OLIGOMERS)
+                             SELECTION_TYPE_OLIGOMERS)
                             continue;
                         }
                     }
                 }
 
               if(iter == 0 && m_calcOptions.polymerEntities() &
-                                libmass::POLYMER_CHEMENT_LEFT_END_MODIF)
+                                POLYMER_CHEMENT_LEFT_END_MODIF)
                 {
                   // We are iterating in the monomer that is at the
                   // beginning of the polymer sequence. We should
@@ -333,7 +333,7 @@ PkaPhPi::calculateCharges()
                   // of the polymer sequence region.
 
                   int ret = accountPolymerEndModif(
-                    libmass::POLYMER_CHEMENT_LEFT_END_MODIF, *chemicalGroup);
+                    POLYMER_CHEMENT_LEFT_END_MODIF, *chemicalGroup);
                   if(ret >= 0)
                     {
                       // 			qDebug() << __FILE__ << __LINE__
@@ -344,12 +344,11 @@ PkaPhPi::calculateCharges()
                     }
                 }
 
-              if(iter == polymerSize - 1 &&
-                 m_calcOptions.polymerEntities() &
-                   libmass::POLYMER_CHEMENT_RIGHT_END_MODIF)
+              if(iter == polymerSize - 1 && m_calcOptions.polymerEntities() &
+                                              POLYMER_CHEMENT_RIGHT_END_MODIF)
                 {
                   int ret = accountPolymerEndModif(
-                    libmass::POLYMER_CHEMENT_RIGHT_END_MODIF, *chemicalGroup);
+                    POLYMER_CHEMENT_RIGHT_END_MODIF, *chemicalGroup);
                   if(ret >= 0)
                     {
                       // 			qDebug() << __FILE__ << __LINE__
@@ -360,8 +359,7 @@ PkaPhPi::calculateCharges()
                     }
                 }
 
-              if(m_calcOptions.monomerEntities() &
-                   libmass::MONOMER_CHEMENT_MODIF &&
+              if(m_calcOptions.monomerEntities() & MONOMER_CHEMENT_MODIF &&
                  seqMonomer->isModified())
                 {
                   int ret = accountMonomerModif(*seqMonomer, *chemicalGroup);
@@ -396,20 +394,19 @@ PkaPhPi::calculateCharges()
           // for (int kter = 0; kter < monomer->propList().size(); ++kter)
 
           // 	    qDebug() << __FILE__ << __LINE__
-          // 		      << "End dealing with libmass::Monomer:" <<
-          // seqMonomer->name()
+          // 		      << "End dealing with Monomer:" << seqMonomer->name()
           // 		      << "position:" << jter + 1;
         }
       // End of
       // for (int jter = startIndex; jter < endIndex + 1; ++jter)
 
       // 	qDebug() << __FILE__ << __LINE__
-      // 		  << "End dealing with libmass::Coordinates";
+      // 		  << "End dealing with Coordinates";
     }
   // End of
   // for (int iter = 0; iter < coordinateList.size(); ++iter)
 
-  // We have finished processing all the libmass::Coordinates in the list.
+  // We have finished processing all the Coordinates in the list.
 
   return processedChemicalGroups;
 }
@@ -603,18 +600,17 @@ PkaPhPi::calculateChargeRatio(double pka, bool acidCharged)
 
 
 int
-PkaPhPi::accountPolymerEndModif(int endModif,
-                                const libmass::ChemicalGroup &group)
+PkaPhPi::accountPolymerEndModif(int endModif, const ChemicalGroup &group)
 {
   QString modifName;
-  libmass::ChemicalGroupRule *rule = 0;
+  ChemicalGroupRule *rule = 0;
 
   int count = 0;
 
   // Get the name of the modification of the polymer(if any) and get
   // the rule dealing with that polymer modification(if any).
 
-  if(endModif == libmass::POLYMER_CHEMENT_LEFT_END_MODIF)
+  if(endModif == POLYMER_CHEMENT_LEFT_END_MODIF)
     {
       modifName = m_polymer.leftEndModif().name();
 
@@ -634,7 +630,7 @@ PkaPhPi::accountPolymerEndModif(int endModif,
       // 	</chemgrouprule>
       //       </mnmchemgroup>
     }
-  else if(endModif == libmass::POLYMER_CHEMENT_RIGHT_END_MODIF)
+  else if(endModif == POLYMER_CHEMENT_RIGHT_END_MODIF)
     {
       modifName = m_polymer.rightEndModif().name();
 
@@ -696,12 +692,12 @@ PkaPhPi::accountPolymerEndModif(int endModif,
   // for. At this point we should now what action to take for this
   // group.
 
-  if(rule->outcome() == libmass::CHEMGROUP_RULE_LOST)
+  if(rule->outcome() == CHEMGROUP_RULE_LOST)
     {
       // We do not use the current chemical group 'group' because the
       // polymer end's modification has abolished it.
     }
-  else if(rule->outcome() == libmass::CHEMGROUP_RULE_PRESERVED)
+  else if(rule->outcome() == CHEMGROUP_RULE_PRESERVED)
     {
       double charge = calculateChargeRatio(group.pka(), group.isAcidCharged());
       if(charge < 0)
@@ -724,7 +720,7 @@ PkaPhPi::accountPolymerEndModif(int endModif,
   // of the polymer is modified. We'll see what chemgroup(s) this
   // modification brings to the polymer sequence.
 
-  int index = libmass::Modif::isNameInList(modifName, *mpa_modifList);
+  int index = Modif::isNameInList(modifName, *mpa_modifList);
 
   if(index == -1)
     {
@@ -735,20 +731,20 @@ PkaPhPi::accountPolymerEndModif(int endModif,
       return count;
     }
 
-  const libmass::Modif *modif = mpa_modifList->at(index);
+  const Modif *modif = mpa_modifList->at(index);
   Q_ASSERT(modif);
 
   for(int jter = 0; jter < modif->propList().size(); ++jter)
     {
-      libmass::Prop *prop = modif->propList().at(jter);
+      Prop *prop = modif->propList().at(jter);
 
       if(prop->name() != "CHEMICAL_GROUP")
         continue;
 
       // Get the chemical group out of the property.
 
-      const libmass::ChemicalGroup *chemicalGroup =
-        static_cast<const libmass::ChemicalGroup *>(prop->data());
+      const ChemicalGroup *chemicalGroup =
+        static_cast<const ChemicalGroup *>(prop->data());
 
       double charge = calculateChargeRatio(chemicalGroup->pka(),
                                            chemicalGroup->isAcidCharged());
@@ -765,11 +761,10 @@ PkaPhPi::accountPolymerEndModif(int endModif,
 
 
 int
-PkaPhPi::accountMonomerModif(const libmass::Monomer &monomer,
-                             libmass::ChemicalGroup &group)
+PkaPhPi::accountMonomerModif(const Monomer &monomer, ChemicalGroup &group)
 {
   QString modifName;
-  libmass::ChemicalGroupRule *rule = 0;
+  ChemicalGroupRule *rule = 0;
 
   int count = 0;
 
@@ -780,7 +775,7 @@ PkaPhPi::accountMonomerModif(const libmass::Monomer &monomer,
 
   for(int iter = 0; iter < monomer.modifList()->size(); ++iter)
     {
-      libmass::Modif *iterModif = monomer.modifList()->at(iter);
+      Modif *iterModif = monomer.modifList()->at(iter);
 
       // Get the name of the modification of the monomer(if any) and get
       // the rule dealing with that monomer modification(if any).
@@ -842,12 +837,12 @@ PkaPhPi::accountMonomerModif(const libmass::Monomer &monomer,
       // were looking for. At this point we should know what action to
       // take for this chemgroup.
 
-      if(rule->outcome() == libmass::CHEMGROUP_RULE_LOST)
+      if(rule->outcome() == CHEMGROUP_RULE_LOST)
         {
           // We do not use the current chemical group 'group' because the
           // monomer modification has abolished it.
         }
-      else if(rule->outcome() == libmass::CHEMGROUP_RULE_PRESERVED)
+      else if(rule->outcome() == CHEMGROUP_RULE_PRESERVED)
         {
           double charge =
             calculateChargeRatio(group.pka(), group.isAcidCharged());
@@ -870,7 +865,7 @@ PkaPhPi::accountMonomerModif(const libmass::Monomer &monomer,
       // modified. We'll see what chemgroup(s) this modification brings to
       // the polymer sequence.
 
-      int index = libmass::Modif::isNameInList(modifName, *mpa_modifList);
+      int index = Modif::isNameInList(modifName, *mpa_modifList);
 
       if(index == -1)
         {
@@ -881,20 +876,20 @@ PkaPhPi::accountMonomerModif(const libmass::Monomer &monomer,
           return count;
         }
 
-      libmass::Modif *modif = mpa_modifList->at(index);
+      Modif *modif = mpa_modifList->at(index);
       Q_ASSERT(modif);
 
       for(int jter = 0; jter < modif->propList().size(); ++jter)
         {
-          libmass::Prop *prop = modif->propList().at(jter);
+          Prop *prop = modif->propList().at(jter);
 
           if(prop->name() != "CHEMICAL_GROUP")
             continue;
 
           // Get the chemical group out of the property.
 
-          const libmass::ChemicalGroup *chemicalGroup =
-            static_cast<const libmass::ChemicalGroup *>(prop->data());
+          const ChemicalGroup *chemicalGroup =
+            static_cast<const ChemicalGroup *>(prop->data());
 
           double charge = calculateChargeRatio(chemicalGroup->pka(),
                                                chemicalGroup->isAcidCharged());
